// Kairos WP Plugin - Authentication Module (_auth.js) - NOTE: Filename in comment is wrong, should be _settings-page.js
// Handles token balance display, conditional purchase section, and Stripe checkout initiation.

(function($) { // Use an IIFE
    "use strict";

    // Assumes kairosWpApi and utility functions (like kairos_wp_get_message) are globally available
    // or loaded as dependencies via wp_enqueue_script.

    // Function to format numbers (if not globally available)
    function kairos_wp_format_number(num) {
        if (typeof num !== 'number') {
            // Try to parse if it's a string number
            const parsedNum = parseInt(num, 10);
            if (isNaN(parsedNum)) {
                 return num; // Return as is if not parseable
            }
            num = parsedNum;
        }
        return num.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ","); // Basic thousand separator
    }

    // Function to display messages (e.g., Stripe success/error)tts-floating-icon
    function showStripeMessage(message, type = 'success') {
        const messageDiv = $('#kairos-wp-stripe-message');
        if(messageDiv.length) { // Check if element exists
            messageDiv.text(message).removeClass('success error').addClass(type).show();
            // Optionally hide after a few seconds
            // setTimeout(() => messageDiv.hide(), 5000);
        } else {
            console.warn("Stripe message container #kairos-wp-stripe-message not found.");
        }
    }

    // Function to fetch token quota status
    function fetchTokenQuotaStatus() { // Renamed function
        const token = localStorage.getItem('kairos_wp_jwt');
        if (!token) {
            console.error('JWT not found for fetching quota status.');
            $('#kairos-wp-token-packages').hide();
            $('#kairos-wp-low-token-warning-settings').hide();
            $('#kairos-wp-token-quota-status').text(''); // Corrected ID selector
            return;
        }

        const quotaValueEl = $('#kairos-wp-token-quota-status'); // Corrected ID selector to match HTML
        if(quotaValueEl.length) {
             quotaValueEl.text(kairos_wp_object?.messages?.loading || 'Loading...');
        } else {
             console.warn("Quota display element #kairos-wp-token-quota-status not found."); // Updated warning message
        }

        // --- Call Consolidated Auth Endpoint via Fetch ---
        if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') {
            console.error("[Settings Page] Consolidated Auth API Endpoint URL not available for get-quota.");
            if(quotaValueEl.length) quotaValueEl.text(kairos_wp_object?.messages?.error || 'Error (Config)');
            $('#kairos-wp-token-packages').hide(); $('#kairos-wp-low-token-warning-settings').hide();
            return;
        }
        const apiUrl = window.kairosWpApi.AUTH_ENDPOINT;

        fetch(`${apiUrl}?action=get-quota`, { // Use GET and add action as query param
            method: 'GET',
            headers: {
                'Authorization': `Bearer ${token}` // Send JWT token in header
            }
        })
        .then(response => {
            if (!response.ok) {
                return response.json().catch(() => ({})).then(errorData => {
                    const message = errorData?.message || `HTTP error ${response.status}`;
                    const code = errorData?.error || 'UNKNOWN_ERROR';
                    const error = new Error(message); error.code = code; throw error;
                });
            } return response.json();
        })
        .then(data => {
            const packagesSection = $('#kairos-wp-token-packages');
            const lowTokenWarning = $('#kairos-wp-low-token-warning-settings');

            if (data.success && typeof data.data?.limit !== 'undefined' && typeof data.data?.consumed !== 'undefined') { // Access data via data.data
                const limit = parseInt(data.data.limit, 10);
                const consumed = parseInt(data.data.consumed, 10);
                const remaining = limit - consumed; // Sigue siendo útil para la lógica de "low quota"

                if(quotaValueEl.length) {
                    // Cambiar la etiqueta del contenedor si existe (asumiendo que el span está dentro de un <p> con un <strong> para la etiqueta)
                    const $quotaLabel = quotaValueEl.closest('p').find('strong:first-child');
                    if ($quotaLabel.length) {
                        $quotaLabel.text(kairos_wp_get_message('quota-usage-label') || 'Uso de Tokens:');
                    }

                    if (limit > 0) {
                        const formatter = new Intl.NumberFormat();
                        const formattedConsumed = formatter.format(consumed);
                        const formattedLimit = formatter.format(limit);
                        let displayString = `${formattedConsumed} / ${formattedLimit}`;
                        
                        quotaValueEl.text(displayString);
                        // Cambiar color si se excede la cuota
                        if (consumed > limit) {
                            quotaValueEl.css('color', 'red').attr('title', kairos_wp_get_message('quota-exceeded-tooltip') || 'Has excedido tu cuota de tokens.');
                        } else {
                            quotaValueEl.css('color', '').attr('title', ''); // Reset color and tooltip
                        }
                    } else {
                        quotaValueEl.text(kairos_wp_get_message('quota-no-active') || 'No active quota'); 
                        quotaValueEl.css('color', '').attr('title', ''); // Reset color and tooltip
                    }
                }

                // Conditional display logic based on quota
                const lowQuotaThreshold = 10000; // Example threshold
                if (limit === 0 || (limit > 0 && remaining < lowQuotaThreshold)) {
                    if(packagesSection.length) packagesSection.show();
                    if(lowTokenWarning.length) lowTokenWarning.show();
                } else {
                    if(packagesSection.length) packagesSection.hide();
                    if(lowTokenWarning.length) lowTokenWarning.hide();
                }
            } else {
                console.error('Error fetching token quota via API:', data?.message || 'Unknown API error structure'); // Corrected log message source
                if(quotaValueEl.length) {
                    quotaValueEl.text(kairos_wp_object?.messages?.error || 'Error (API)');
                }
                if(packagesSection.length) packagesSection.hide();
                if(lowTokenWarning.length) lowTokenWarning.hide();
            }
        })
        .catch(error => {
            console.error('Fetch error fetching token quota:', error);
            let displayMessage = kairos_wp_get_message('error-network') || 'Error (Network)';
            if (error.code === 'PROFILE_NOT_FOUND') {
                displayMessage = kairos_wp_get_message('error-profile-not-found') || 'Error: User profile not found.';
            } else if (error.code === 'TOKEN_EXPIRED' || error.code === 'INVALID_TOKEN') {
                 displayMessage = kairos_wp_get_message('error-session-expired') || 'Session expired. Please log in again.';
                 // Optionally trigger logout UI update
                 // updateAuthUIState(null); // Requires exposing this function or using events
            } else if (error.message) {
                 displayMessage = (kairos_wp_get_message('error-prefix') || 'Error: ') + error.message;
            }

            if(quotaValueEl.length) {
                quotaValueEl.text(displayMessage);
            }
            $('#kairos-wp-token-packages').hide();
            $('#kairos-wp-low-token-warning-settings').hide();
        });
    }

    // Function to handle Stripe checkout (DEPRECATED - Using Payment Links now)
    function handleStripeCheckout(priceId) {
        console.warn("handleStripeCheckout function called, but it's deprecated. Use direct payment links.");
        showStripeMessage('Checkout via this button is deprecated. Please use the provided payment links.', 'error');
        // Optionally hide spinner if it was shown by mistake
        const spinner = $('#kairos-wp-stripe-spinner');
        if(spinner.length) spinner.hide();
        /* // Original AJAX call commented out
        const token = localStorage.getItem('kairos_wp_jwt');
        if (!token) {
            showStripeMessage(kairos_wp_object?.messages?.login_required || 'Please log in to purchase tokens.', 'error');
            return;
        }

        const spinner = $('#kairos-wp-stripe-spinner');
        const messageDiv = $('#kairos-wp-stripe-message');
        if(spinner.length) spinner.css('display', 'inline-block'); // Show spinner
        if(messageDiv.length) messageDiv.hide(); // Hide previous messages

        // Use the WP AJAX proxy action
        $.ajax({
            url: kairos_wp_object.ajax_url,
            method: 'POST',
            data: {
                action: 'kairos_wp_create_stripe_checkout_proxy',
                nonce: kairos_wp_object.nonce,
                price_id: priceId,
                jwt_token: token // Add JWT token here
            },
            // No need for beforeSend with JWT header when using WP AJAX proxy
            success: function(response) {
                if(spinner.length) spinner.hide();
                if (response.success && response.data.redirect_url) {
                    // Redirect to Stripe checkout
                    window.location.href = response.data.redirect_url;
                } else {
                    showStripeMessage(response.data?.message || kairos_wp_object?.messages?.stripe_error || 'Could not initiate checkout.', 'error');
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                 if(spinner.length) spinner.hide();
                 console.error('AJAX error initiating Stripe checkout:', textStatus, errorThrown);
                showStripeMessage(kairos_wp_object?.messages?.stripe_error || 'An error occurred. Please try again.', 'error');
            }
        });
        */ // Corrected closing comment tag position
    } // Corrected closing brace position

    // Document Ready
    $(function() {
        // Initial check removed - rely on custom event 'kairos_wp_auth_ui_ready'

        // Event listener for DEPRECATED purchase buttons (keep for safety, but should not be used)
        // Using '.wrap' as a sufficiently high-level static parent
        $('.wrap').on('click', '.kairos-wp-buy-tokens-btn', function() {
            const priceId = $(this).data('price-id');
            if (priceId) {
                handleStripeCheckout(priceId);
            } else {
                 // --- CORRECTED: Check for payment link URL instead of priceId ---
                 const paymentLinkUrl = $(this).data('payment-link-url');
                 if (paymentLinkUrl) {
                     const token = localStorage.getItem('kairos_wp_jwt');
                     if (!token) {
                         showStripeMessage(kairos_wp_get_message('error-login-required-purchase') || 'Please log in to purchase.', 'error');
                         return;
                     }
                     // Decode JWT to get user ID (simple client-side decode for non-critical data)
                     let userId = '';
                     try {
                         const base64Url = token.split('.')[1];
                         const base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');
                         const jsonPayload = decodeURIComponent(atob(base64).split('').map(function(c) {
                             return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
                         }).join(''));
                         userId = JSON.parse(jsonPayload).sub; // Get user ID (subject)
                     } catch (e) {
                         console.error("Failed to decode JWT or get user ID:", e);
                         showStripeMessage(kairos_wp_get_message('error-session-verification-failed') || 'Could not verify user session. Please log out and log back in.', 'error');
                         return;
                     }

                     if (!userId) {
                          showStripeMessage(kairos_wp_get_message('error-user-identification-failed') || 'Could not identify user. Please log out and log back in.', 'error');
                          return;
                     }

                     // Replace placeholder and redirect
                     const finalPaymentLink = paymentLinkUrl.replace('USER_ID_PLACEHOLDER', userId);
                     window.location.href = finalPaymentLink;

                 } else {
                    console.error('Payment Link URL not found for button.');
                    showStripeMessage(kairos_wp_get_message('error-payment-link-missing') || 'Configuration error: Payment link missing.', 'error');
                 }
            }
        });

        // Check for Stripe redirect status messages (Keep this logic for Payment Links)
        const urlParams = new URLSearchParams(window.location.search);
        if (urlParams.has('stripe_status')) {
            const status = urlParams.get('stripe_status');
            if (status === 'success') {
                showStripeMessage(kairos_wp_object?.messages?.success_payment || 'Payment successful! Your token quota will be updated shortly.', 'success'); // Updated message
                 // Fetch quota status again only if user info section is visible
                 if ($('#kairos-wp-user-info-section').length && $('#kairos-wp-user-info-section').is(':visible')) {
                    fetchTokenQuotaStatus(); // Call new function
                 }
            } else if (status === 'cancel') {
                showStripeMessage(kairos_wp_object?.messages?.error_payment_cancelled || 'Payment cancelled. Your token quota has not changed.', 'error'); // Updated message
            }
            // Clean the URL parameters to avoid showing message on refresh
            if (window.history.replaceState) {
                 const cleanURL = window.location.pathname + window.location.search.replace(/[\?&]stripe_status=[^&]+/, '').replace(/^&/, '?') + window.location.hash;
                 window.history.replaceState({ path: cleanURL }, '', cleanURL);
            }
        }

         // --- Add listener for custom event when auth UI is ready (triggered by _auth.js) ---
         $(document).on('kairos_wp_auth_ui_ready', function() {
             fetchTokenQuotaStatus(); // Call new function
         });

          // --- Add listener for custom event when user logs out ---
         // This assumes the _auth.js module triggers 'kairos_wp_user_logged_out' on the document
         $(document).on('kairos_wp_user_logged_out', function() {
             // Hide token packages and warning on logout
             $('#kairos-wp-token-packages').hide();
             $('#kairos-wp-low-token-warning-settings').hide();
             // Clear quota display
             $('#kairos-wp-token-quota-status').text(''); // Corrected ID selector
             // Hide banner on logout as well
             $('#kairos-wp-dynamic-banner-placeholder').empty().hide();
         });

         // --- Function to fetch and display the dynamic banner ---
         function fetchAndDisplayBanner() {
            const token = localStorage.getItem('kairos_wp_jwt');
            if (!token) {
                // No need to fetch if not logged in
                $('#kairos-wp-dynamic-banner-placeholder').empty().hide();
                return;
            }

            const bannerPlaceholder = $('#kairos-wp-dynamic-banner-placeholder');
            if (!bannerPlaceholder.length) {
                console.warn("Dynamic banner placeholder #kairos-wp-dynamic-banner-placeholder not found.");
                return;
            }

            // --- Call Consolidated Auth Endpoint via Fetch ---
            if (!window.kairosWpApi || typeof window.kairosWpApi.AUTH_ENDPOINT === 'undefined') { // Check for consolidated endpoint
                console.error("[Settings Page] Consolidated Auth API Endpoint URL not available for get-dynamic-banner.");
                bannerPlaceholder.empty().hide(); // Hide on config error
                return;
            }
            const apiUrl = window.kairosWpApi.AUTH_ENDPOINT; // Use consolidated endpoint

            fetch(`${apiUrl}?action=get-dynamic-banner`, { // Use GET and add action query param
                method: 'GET',
                headers: { 'Authorization': `Bearer ${token}` }
            })
            .then(response => {
                if (!response.ok) {
                    return response.json().catch(() => ({})).then(errorData => {
                        const message = errorData?.message || `HTTP error ${response.status}`;
                        throw new Error(message);
                    });
                }
                return response.json();
            })
            .then(data => {
                if (data.success === true && typeof data.data?.bannerHtml === 'string' && data.data.bannerHtml.trim().length > 0) {
                    bannerPlaceholder.html(data.data.bannerHtml).show();
                } else {
                    bannerPlaceholder.empty().hide();
                    if (!data.success) {
                         console.error('Error fetching dynamic banner:', data.message || 'Unknown error from API');
                    } else if (!data.data?.bannerHtml) {
                         console.warn('Banner HTML content missing in API response.');
                    }
                }
            })
            .catch(error => {
                console.error('Fetch error fetching dynamic banner:', error);
                bannerPlaceholder.empty().hide(); // Hide on fetch error
            });
         } // Correctly closing the fetchAndDisplayBanner function

         // --- Call fetchAndDisplayBanner when auth UI is ready ---
         $(document).on('kairos_wp_auth_ui_ready', function() {
             fetchAndDisplayBanner(); // Fetch banner when UI is confirmed ready
         }); // Correctly closing the .on() call

        // --- Redeem Coupon Button Handler ---
        // Asegurarse de que el DOM esté completamente cargado para este selector también
        $(document).on('click', '#kairos-wp-redeem-coupon-button', async function() {
            console.log('[Kairos WP Settings] Redeem coupon button clicked.'); // Log inicial
            const $button = $(this);
            const $input = $('#kairos-wp-redeem-coupon-code');
            const $messageDiv = $('#kairos-wp-redeem-coupon-message');
            const $spinner = $('#kairos-wp-redeem-coupon-spinner');
            
            const couponCode = $input.val().trim();
            const token = localStorage.getItem('kairos_wp_jwt');

            $messageDiv.removeClass('success error').text('').hide();

            if (!token) {
                $messageDiv.text(kairos_wp_get_message('error-login-required-purchase') || 'Please log in to redeem a coupon.').addClass('error').show();
                return;
            }
            if (!couponCode) {
                $messageDiv.text(kairos_wp_get_message('error-coupon-code-empty') || 'Please enter a coupon code.').addClass('error').show(); // Necesitaremos añadir 'error-coupon-code-empty' a los mensajes
                return;
            }

            if (!window.kairosWpApi || typeof window.kairosWpApi.callRedeemCouponApi !== 'function') {
                console.error("[Settings Page] callRedeemCouponApi function not available on window.kairosWpApi.");
                $messageDiv.text(kairos_wp_get_message('error-internal-api-config') || 'Internal error (API Configuration).').addClass('error').show();
                return;
            }

            $button.prop('disabled', true);
            $spinner.css('display', 'inline-block');

            console.log('[Kairos WP Settings] Attempting to call callRedeemCouponApi with token and couponCode:', couponCode); // Log antes de la llamada

            try {
                const response = await window.kairosWpApi.callRedeemCouponApi(token, couponCode);
                console.log('[Kairos WP Settings] API callRedeemCouponApi response:', response); // Log de la respuesta

                if (response.success) {
                    $messageDiv.text(response.message || kairos_wp_get_message('success-coupon-redeemed') || 'Coupon redeemed successfully!').addClass('success').show(); // Necesitaremos 'success-coupon-redeemed'
                    fetchTokenQuotaStatus(); // Actualizar visualización de cuota
                    $input.val(''); // Limpiar el campo del cupón
                } else {
                    // Usar el mensaje de error específico de la API si está disponible
                    const errorMessage = response.data?.message || response.message || kairos_wp_get_message('error-coupon-invalid') || 'Invalid or expired coupon code.'; // Necesitaremos 'error-coupon-invalid'
                    $messageDiv.text(errorMessage).addClass('error').show();
                    console.error("Error redeeming coupon:", response.data || response);
                }
            } catch (error) {
                console.error('Error calling redeem coupon API:', error);
                let errorMessage = kairos_wp_get_message('error-general'); // Mensaje genérico
                if (error && error.status && error.data && error.data.message) { // Verificar que error y sus propiedades existan
                    errorMessage = error.data.message; // Mensaje específico de la API
                } else if (error && error.message) { // Verificar que error y error.message existan
                    errorMessage = error.message;
                }
                $messageDiv.text(errorMessage).addClass('error').show();
            } finally {
                $spinner.hide();
                $button.prop('disabled', false);
            }
        });


    }); // End Document Ready

})(jQuery); // End IIFE
