// Kairos WP Plugin - UI Helpers Module (_ui-helpers.js)
// Contains functions for managing UI elements like modals, tooltips, notices.

console.log('Kairos WP: _ui-helpers.js loaded'); // Log at the beginning of the file

// Define functions directly on window object
window.kairos_wp_escape_key_handler = function(e) {
    if (e.key === "Escape" && window.isThickboxInterceptorActive) {
        e.preventDefault();
        e.stopPropagation();
        return false;
    }
};

window.ensureThickboxInterceptor = function() {
    if (jQuery('#kairos-wp-thickbox-interceptor').length === 0) {
        jQuery('body').append('<div id="kairos-wp-thickbox-interceptor"></div>');
        jQuery('#kairos-wp-thickbox-interceptor').on('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
        });
    }
};

window.showThickboxLoader = function(agentName, messageKey) {
    console.log('Kairos WP: showThickboxLoader called for agent:', agentName, 'with message key:', messageKey); // Log call
    window.ensureThickboxInterceptor();
    jQuery('#kairos-wp-thickbox-interceptor').show();
    jQuery(document).on('keydown.kairos_wp_thickbox', window.kairos_wp_escape_key_handler);
    window.isThickboxInterceptorActive = true;

    const $contentContainer = jQuery('#kairos-wp-thickbox-loader-content');
    const $avatar = jQuery('#kairos-wp-thickbox-loader-avatar');
    const $text = jQuery('#kairos-wp-thickbox-loader-text');
    let avatarSrc = '';
    // Usar claves de mensaje para los textos por defecto
    let defaultMessage = kairos_wp_get_message('thickbox-message-default') || 'Processing...'; // Fallback por si la clave no existe
    let title = kairos_wp_get_message('thickbox-title-default') || 'Processing...'; // Fallback

    if (agentName === 'Pablo') {
        title = kairos_wp_get_message('thickbox-title-pablo') || 'Pablo (AI Developer)'; // Fallback
        defaultMessage = kairos_wp_get_message('pablo-generating-php'); 
        if (kairos_wp_object.plugin_url) {
            avatarSrc = kairos_wp_object.plugin_url + 'assets/images/avatars/pablo_avatar.png';
        } else {
            console.warn("kairos_wp_object.plugin_url not localized. Avatar paths might be incorrect.");
            avatarSrc = '../assets/images/avatars/pablo_avatar.png';
        }
    } else if (agentName === 'Alex') {
        title = kairos_wp_get_message('thickbox-title-alex') || 'Alex (AI Reviewer)'; // Fallback
        defaultMessage = kairos_wp_get_message('alex-reviewing'); 
        if (kairos_wp_object.plugin_url) {
            avatarSrc = kairos_wp_object.plugin_url + 'assets/images/avatars/alex_avatar.png';
        } else {
            console.warn("kairos_wp_object.plugin_url not localized. Avatar paths might be incorrect.");
            avatarSrc = '../assets/images/avatars/alex_avatar.png';
        }
    } else if (agentName === 'Lola') {
        title = kairos_wp_get_message('thickbox-title-lola') || 'Lola (AI Consultant)'; // Fallback
        // defaultMessage se usa si messageKey es nulo. messageKey ya viene de get_message en el llamador.
        if (kairos_wp_object.plugin_url) {
            avatarSrc = kairos_wp_object.plugin_url + 'assets/images/avatars/lola_avatar.png';
        } else {
            console.warn("kairos_wp_object.plugin_url not localized. Avatar paths might be incorrect.");
            avatarSrc = '../assets/images/avatars/lola_avatar.png';
        }
    } else if (agentName === 'System') {
        title = kairos_wp_get_message('thickbox-title-system') || 'System Processing'; // Fallback
        avatarSrc = ''; 
    } else {
        console.warn("Unknown agent name for ThickBox loader:", agentName);
        // title ya está configurado con 'thickbox-title-default'
        avatarSrc = '';
    }

    if (avatarSrc) {
        $avatar.attr('src', avatarSrc).show();
    } else {
        $avatar.hide();
    }

    const message = messageKey ? kairos_wp_get_message(messageKey) : defaultMessage; // messageKey ya es un resultado de kairos_wp_get_message
    console.log('Kairos WP: Message resolved to:', message);
    // Si message (que viene de messageKey o defaultMessage) es nulo o vacío, usar el fallback traducido.
    $text.text(message || kairos_wp_get_message('thickbox-message-default') || 'Processing...');

    const width = 450;
    const height = 280;
    if (typeof tb_show === 'function') {
        tb_show(title, `#TB_inline?inlineId=kairos-wp-thickbox-loader-container&width=${width}&height=${height}`, null);
        setTimeout(function() {
            const $TB_window = jQuery('#TB_window');
            const $TB_ajaxContent = jQuery('#TB_ajaxContent');
            const $TB_closeWindowButton = jQuery('#TB_closeWindowButton');
            if ($TB_closeWindowButton.length) {
                $TB_closeWindowButton.css('display', 'none');
            } else {
                console.warn("[Kairos Debug] Close button (#TB_closeWindowButton) not found.");
            }
            if ($TB_ajaxContent.length) {
                $TB_ajaxContent.css({
                    'display': 'flex',
                    'align-items': 'center',
                    'justify-content': 'center',
                    'overflow': 'hidden',
                    'height': '100%',
                    'width': '100%',
                    'padding': '0',
                    'box-sizing': 'border-box'
                });
            } else {
                console.warn("[Kairos Debug] Content area (#TB_ajaxContent) not found.");
            }
        }, 50);
    } else {
        console.error("ThickBox (tb_show) function not available.");
        alert(kairos_wp_get_message('error-thickbox-unavailable') || 'Error: ThickBox is not available.');
    }
};

window.hideThickboxLoader = function() {
    jQuery('#kairos-wp-thickbox-interceptor').hide();
    jQuery(document).off('keydown.kairos_wp_thickbox', window.kairos_wp_escape_key_handler);
    window.isThickboxInterceptorActive = false;
    if (typeof tb_remove === 'function') {
        tb_remove();
    } else {
        console.error("ThickBox (tb_remove) function not available.");
    }
};

window.updateTokenMetaboxDisplay = function(tokensData) {
    const $metabox = jQuery('.kairos-wp-token-economy-metabox');
    if (!$metabox.length) {
        console.warn("[Kairos Debug] Token Economy Metabox not found for update.");
        return;
    }
    tokensData = (typeof tokensData === 'object' && tokensData !== null) ? tokensData : {};
    const formatTokens = (value) => {
        const num = parseInt(value, 10);
        return !isNaN(num) && num >= 0 ? new Intl.NumberFormat().format(num) : '0';
    };
    let $ul = $metabox.find('ul.kairos-wp-consumption-list');
    if (!$ul.length) {
        const $h4 = $metabox.find('h4');
        if ($h4.length) {
            $h4.after('<ul class="kairos-wp-consumption-list" style="list-style: none; padding-left: 0; margin-top: 5px; margin-bottom: 10px;"></ul>');
            $ul = $metabox.find('ul.kairos-wp-consumption-list');
        } else {
            console.error("[Kairos Debug] Cannot find H4 to insert consumption list.");
            return;
        }
    }
    const updateListItem = (key, label) => {
        let $li = $ul.find(`li[data-agent="${key}"]`);
        const value = tokensData[key];
        const formattedValue = formatTokens(value);
        const displayValue = parseInt(formattedValue.replace(/,/g, ''), 10);
        if (!$li.length) {
            $ul.append(`<li data-agent="${key}" style="display: none;"></li>`);
            $li = $ul.find(`li[data-agent="${key}"]`);
        }
        if (displayValue > 0) {
            const text = `${label}: <strong>${formattedValue}</strong>`;
            $li.html(text).show();
        } else {
            $li.hide();
        }
    };
    updateListItem('lola_initial', kairos_wp_get_message('Lola (Initial)') || 'Lola (Initial)');
    updateListItem('lola_refine', kairos_wp_get_message('Lola (Refine)') || 'Lola (Refine)');
    updateListItem('pablo', kairos_wp_get_message('Pablo (Generate)') || 'Pablo (Generate)');
    updateListItem('alex', kairos_wp_get_message('Alex (Review)') || 'Alex (Review)');
    const cumulativeValue = tokensData['cumulative'];
    const formattedCumulative = formatTokens(cumulativeValue);
    const displayCumulative = parseInt(formattedCumulative.replace(/,/g, ''), 10);
    let $totalP = $metabox.find('p.kairos-wp-cumulative-total');
    if (!$totalP.length) {
        $ul.after(`<p class="kairos-wp-cumulative-total" style="border-top: 1px solid #eee; padding-top: 10px; display: none;"></p>`);
        $totalP = $metabox.find('p.kairos-wp-cumulative-total');
    }
    if (displayCumulative > 0) {
        let totalText = kairos_wp_get_message('Total Consumed:') || 'Total Consumed: %s';
        if (totalText.includes('%s')) {
            totalText = totalText.replace('%s', formattedCumulative);
        } else {
            totalText += ` ${formattedCumulative}`;
        }
        $totalP.html(`<strong>${totalText}</strong>`).show();
    } else {
        $totalP.hide();
    }
};

window.fetchAndUpdateMetaboxBalance = async function(token) {
    const $metaboxContainer = jQuery('.kairos-wp-token-economy-metabox');
    if (!$metaboxContainer.length) {
        console.warn("[UI Helpers] Token Economy Metabox container not found.");
        return;
    }
    const $balanceLabel = $metaboxContainer.find('p:first-child > strong');
    const $balanceValue = jQuery('#kairos-wp-available-token-balance-value');
    if (!token) {
        console.warn("[UI Helpers] No token provided for fetchAndUpdateMetaboxBalance.");
        if ($balanceLabel.length) $balanceLabel.text(kairos_wp_get_message('quota-usage-label') || 'Uso de Tokens:');
        if ($balanceValue.length) $balanceValue.text(kairos_wp_get_message('error-login-required-purchase') || 'Login Required');
        return;
    }
    const VERCEL_GET_QUOTA_URL = 'https://kairos-wp.vercel.app/api/auth?action=get-quota';
    if ($balanceLabel.length) {
        $balanceLabel.text(kairos_wp_get_message('quota-usage-label') || 'Uso de Tokens:');
    }
    if ($balanceValue.length) {
        $balanceValue.text(kairos_wp_get_message('loading') || 'Loading...');
    } else {
        console.warn("[UI Helpers] Metabox balance value element #kairos-wp-available-token-balance-value not found.");
    }
    fetch(VERCEL_GET_QUOTA_URL, {
        method: 'GET',
        headers: {
            'Authorization': `Bearer ${token}`,
            'Content-Type': 'application/json'
        }
    })
    .then(response => {
        if (!response.ok) {
            return response.json().then(errData => {
                throw new Error(errData?.message || `HTTP error! status: ${response.status}`);
            });
        }
        return response.json();
    })
    .then(data => {
        if (data.success && data.data && typeof data.data.limit !== 'undefined' && typeof data.data.consumed !== 'undefined') {
            const limit = parseInt(data.data.limit, 10);
            const consumed = parseInt(data.data.consumed, 10);
            const formatter = new Intl.NumberFormat();
            const formattedConsumed = formatter.format(consumed);
            const formattedLimit = formatter.format(limit);
            let displayString = `${formattedConsumed} / ${formattedLimit}`;
            if ($balanceValue.length) {
                $balanceValue.text(displayString);
                if (consumed > limit && limit > 0) {
                    $balanceValue.css('color', 'red').attr('title', kairos_wp_get_message('quota-exceeded-tooltip') || 'Has excedido tu cuota de tokens.');
                } else {
                    $balanceValue.css('color', '').attr('title', '');
                }
            }
        } else {
            console.error('[UI Helpers] Error fetching token quota from API:', data?.message || 'Unexpected API response structure');
            if ($balanceValue.length) {
                $balanceValue.text(kairos_wp_get_message('error') || 'Error').css('color', 'red');
            }
        }
    })
    .catch(error => {
        console.error('[UI Helpers] Fetch error fetching token quota for metabox:', error);
        if ($balanceValue.length) {
            $balanceValue.text(kairos_wp_get_message('error') || 'Error').css('color', 'red');
        }
    });
};

// Functions that were previously inside IIFE and might be called by other parts of the plugin
// (assuming they are not jQuery dependent or $ is passed if they are)
// For simplicity, these are kept outside the jQuery IIFE if they don't directly use $
// or are utility functions that might be used by non-jQuery contexts.
// However, since they use kairos_wp_get_message which depends on kairos_wp_object,
// they should ideally be within a scope where kairos_wp_object is guaranteed.
// For now, assuming kairos_wp_object and kairos_wp_get_message are globally available.

// Notices show after refresh
window.kairos_wp_show_notices_after_refresh = function() {
    jQuery( '#kairos-wp-published-notice-text' ).text( kairos_wp_get_message( jQuery( '#kairos-wp-published-notice-text' ).data( 'message' ) ) );
    jQuery( "#kairos-wp-confidence-notice-text" ).text( kairos_wp_get_message( jQuery( '#kairos-wp-confidence-notice-text' ).data( 'message' ) ) );
    jQuery( "#kairos-wp-edited-code-notice-text" ).text( kairos_wp_get_message( jQuery( '#kairos-wp-edited-code-notice-text' ).data( 'message' ) ) );
};

// Code not generated notice
window.kairos_wp_code_not_generated = function() {
    var code_not_generated = jQuery( '#kairos-wp-after-title' ).data( 'code-not-generated' );
    if ( jQuery( '#kairos-wp-first' ).val() !== '1' ) {
        if ( code_not_generated === 1 ) {
            jQuery( '#kairos-wp-code-not-generated-wrapper' ).addClass( "kairos-wp-notice-show" );
        } else {
            jQuery( '#kairos-wp-code-not-generated-wrapper' ).removeClass( "kairos-wp-notice-show" );
        }
    } else {
        jQuery( '#kairos-wp-code-not-generated-wrapper' ).removeClass( "kairos-wp-notice-show" );
    }
};

// Initial UI Setup Calls - Needs jQuery, so ensure it's called after DOM ready
jQuery(document).ready(function($) {
    // Call functions needed on page load that relate to UI elements handled here
    if (typeof window.kairos_wp_show_notices_after_refresh === 'function') {
        window.kairos_wp_show_notices_after_refresh();
    }
    if (typeof window.kairos_wp_code_not_generated === 'function') {
        window.kairos_wp_code_not_generated();
    }

    // Event handlers that were previously in the IIFE
    $( document ).on( 'click', '.kairos-wp-notice .kairos-wp-notice-close', function() {
		$( this ).parent().removeClass( 'kairos-wp-notice-show' ).fadeOut();
	});
    $( document ).on( 'click', '#kairos-wp-alert-ok', function(e) {
		e.preventDefault();
		var action = $( this ).data( 'action' );
		var $popup = $( '#kairos-wp-alert-popup-overlay' );
		if ( action === 'deepseek-api-url' ) {
			window.open( kairos_wp_object.link, '_blank', 'noopener, noreferrer' );
			$( '#kairos-wp-refresh-popup-overlay' ).fadeIn();
			$( '#kairos-wp-refresh-text' ).text( kairos_wp_get_message( 'notice-refresh-after-api-key' ) );
			$popup.fadeOut();
		} else {
			$popup.fadeOut();
		}
	});
    $( document ).on( 'click', '#kairos-wp-refresh', function() {
		$( '#kairos-wp-refresh-popup-overlay' ).fadeOut();
		$( '#kairos-wp-loader-overlay' ).fadeIn();
		window.location.reload();
	});
    $( document ).on( 'click', '#kairos-wp-edit-cancel', function(e) {
		e.preventDefault();
		$( '#kairos-wp-edit-popup-overlay' ).fadeOut();
	});
    $( document ).on( 'click', '#kairos-wp-rephrase-undo', function(e) {
		e.preventDefault();
		$( '#kairos-wp-rephrased-popup-overlay' ).fadeOut();
		$( '#kairos-wp-rephrased-popup-overlay' ).removeData('rephrased-text');
	});
    $( document ).on( 'click', '.kairos-wp-modal-close', function(e) {
		e.preventDefault();
		$(this).closest('.kairos-wp-modal-content').parent().css('display', 'none');
	});
	$( document ).on( 'click', '.kairos-wp-modal-copy', function(e) {
		e.preventDefault();
		var codeToCopy = $(this).closest('.kairos-wp-modal-content').find('.kairos-wp-modal-body pre').text();
		copyToClipboard(codeToCopy);
		$(this).text(kairos_wp_get_message("copied") || 'Copied!');
		setTimeout(() => {
			$(this).text(kairos_wp_get_message("copy-code") || 'Copy Code');
		}, 1500);
	});
    $( document ).on( 'click', '.kairos-wp-delivery-screen .button-secondary:contains("Mark as Finished")', function(e) {
		e.preventDefault();
		$( '#kairos-wp-confirm-popup-overlay' ).fadeIn();
		$( '#kairos-wp-confirm-text' ).text( kairos_wp_get_message('confirm-mark-as-finished') || 'Are you sure you want to mark this plugin as completed? This will change its status to Published.' );
	});
    $( '#kairos-wp-confirm-no' ).off('click').on('click', function() {
        $( '#kairos-wp-confirm-popup-overlay' ).fadeOut();
    });
});
