// Kairos WP Plugin - Utilities Module (_utils.js)
// Contains general helper functions.

/**
 * Get message from localized array.
 * @param {string} code - The message code.
 * @returns {string} - The localized message or the code itself as fallback.
 */
function kairos_wp_get_message( code ) {
	console.log('Kairos WP: Attempting to get message for code:', code); // Log input code
	// Ensure messages object exists and code is a valid key
	if ( typeof kairos_wp_object !== 'undefined' && typeof kairos_wp_object.pluginMessages === 'object' && kairos_wp_object.pluginMessages !== null && kairos_wp_object.pluginMessages.hasOwnProperty(code) ) {
		const message = kairos_wp_object.pluginMessages[code];
		console.log('Kairos WP: Found message:', message); // Log found message
		return message;
	}
	// Fallback for missing messages
	console.warn('Kairos WP: Missing message for code:', code); // Keep warning
	return code; // Return the code itself as a fallback
}

/**
 * Helper function to decode HTML entities.
 * @param {string} text - The text with HTML entities.
 * @returns {string} - The decoded text.
 */
function decodeHtmlEntities(text) {
	var textArea = document.createElement('textarea');
	textArea.innerHTML = text;
	return textArea.value;
}

/**
 * Copy text to clipboard (uses modern Clipboard API with fallback).
 * @param {string} text - The text to copy.
 */
function copyToClipboard( text ) {
	if ( navigator.clipboard ) {
		navigator.clipboard.writeText( text ).then( function() {
			console.log( 'Text copied to clipboard' );
		}).catch( function( err ) {
			console.error( 'Error copying text: ', err );
			fallbackCopyToClipboard( text ); // Try fallback on error
		});
	} else {
		fallbackCopyToClipboard( text );
	}
}

/**
 * Fallback copy function for older browsers.
 * @param {string} text - The text to copy.
 */
function fallbackCopyToClipboard( text ) {
	var textArea = document.createElement( "textarea" );
	textArea.value = text;

	// Prevent scrolling to bottom
	textArea.style.top = "0";
	textArea.style.left = "0";
	textArea.style.position = "fixed";

	document.body.appendChild( textArea );
	textArea.focus();
	textArea.select();

	try {
		var successful = document.execCommand( 'copy' );
		var msg = successful ? 'successful' : 'unsuccessful';
		console.log( 'Fallback: Copying text command was ' + msg );
	} catch ( err ) {
		console.error( 'Fallback: Oops, unable to copy', err );
	}

	document.body.removeChild( textArea );
}

// Make functions available globally if needed (or use a module pattern later)
// window.kairos_wp_get_message = kairos_wp_get_message;
// window.decodeHtmlEntities = decodeHtmlEntities;
// window.copyToClipboard = copyToClipboard;
