<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-core-framework.php';

class Kairos_WP_Ajax_Framework {
	public $core;

	public function __construct() {
		$this->core = new Kairos_WP_Core_Framework();
	}

	public function kairos_wp_handle_download_zip() {
		error_log('[Kairos WP Ajax DEBUG] Entered kairos_wp_handle_download_zip');

		// Check for required $_POST data first (nonce and post_id are essential)
		if ( ! isset( $_POST['nonce'] ) || ! isset( $_POST['post_id'] ) ) {
			error_log('[Kairos WP Ajax DEBUG] Download ZIP - Missing nonce or post_id in $_POST.');
			wp_send_json_error( array( 'message' => 'error-missing-params' ) ); // Consistent error format
			wp_die();
		}

		if ( ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' ) || ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
			error_log('[Kairos WP Ajax DEBUG] Download ZIP - Nonce verification failed or autosave.');
			wp_send_json_error( array( 'message' => 'error-unauthorized-access' ) );
			wp_die();
		}

		$user = wp_get_current_user();
		if ( ! in_array( 'administrator', $user->roles ) ) { // Simplified check, DOING_AUTOSAVE implies user is logged in and has caps.
			error_log('[Kairos WP Ajax DEBUG] Download ZIP - Permissions check failed.');
			wp_send_json_error( array( 'message' => 'error-unauthorized-access' ) );
			wp_die();
		}

		// The original check for php_code, js_code, css_code in $_POST is no longer needed here
		// as we are fetching them from post_meta. We only need post_id.

            // Get code from post meta
            $post_id   = intval( sanitize_text_field( wp_unslash( $_POST['post_id'] ) ) );
            $php_code  = get_post_meta( $post_id, '_php_output', true );
            $js_code   = get_post_meta( $post_id, '_js_output', true );
            $css_code  = get_post_meta( $post_id, '_css_output', true );

            // Ensure they are strings, even if empty or not found
            $php_code = !empty($php_code) ? $php_code : "<?php\n// No PHP code generated or found.";
            $js_code  = !empty($js_code) ? $js_code : "// No JavaScript code generated or found.";
            $css_code = !empty($css_code) ? $css_code : "/* No CSS code generated or found. */";
            
			$post      = get_post( $post_id );
			$post_slug = sanitize_title( $post->post_name );

			$upload_dir = wp_upload_dir();
			if ( !empty( $upload_dir['error'] ) ) {
				error_log('[Kairos WP Ajax DEBUG] Download ZIP - wp_upload_dir error: ' . $upload_dir['error']);
				wp_send_json_error( array( 'message' => 'error-upload-dir' ) );
				wp_die();
			}
			
			$temp_dir_name = 'kairos-temp-' . $post_slug . '-' . time();
			$temp_plugin_path = $upload_dir['path'] . '/' . $temp_dir_name;
			
			$zip_path   = $upload_dir['path'] . '/' . $post_slug . '.zip';
			$zip_url    = $upload_dir['url'] . '/' . $post_slug . '.zip';

			if ( wp_parse_url( home_url(), PHP_URL_SCHEME ) !== wp_parse_url( $zip_url, PHP_URL_SCHEME ) ) {
				$zip_url = str_replace( wp_parse_url( $zip_url, PHP_URL_SCHEME ) . '://', wp_parse_url( home_url(), PHP_URL_SCHEME ) . '://', $zip_url );
			}

			global $wp_filesystem;
			if ( empty( $wp_filesystem ) ) {
				WP_Filesystem();
			}

			// Create temporary directory structure for zipping
			if ( ! $wp_filesystem->mkdir( $temp_plugin_path ) ) {
				error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to create temp plugin folder: ' . $temp_plugin_path);
				wp_send_json_error( array( 'message' => 'error-temp-folder-creation' ) );
				wp_die();
			}
			// REMOVED creation of assets/js and assets/css subdirectories in temp folder

			// Define paths for temporary files (JS/CSS in root of temp_plugin_path, using legacy names)
			$temp_php_file = $temp_plugin_path . '/plugin-file.php';
			$temp_js_file  = $temp_plugin_path . '/plugin-scripts.js'; // Legacy name
			$temp_css_file = $temp_plugin_path . '/plugin-styles.css'; // Legacy name

			$wp_filesystem->put_contents( $temp_php_file, $php_code, FS_CHMOD_FILE );
			$wp_filesystem->put_contents( $temp_js_file, $js_code, FS_CHMOD_FILE ); // Write even if empty
			$wp_filesystem->put_contents( $temp_css_file, $css_code, FS_CHMOD_FILE ); // Write even if empty

			$zip = new ZipArchive();
			if ( true === $zip->open( $zip_path, ZipArchive::CREATE | ZipArchive::OVERWRITE ) ) {
				// Add files to the root of the folder named $post_slug within the ZIP
				$zip->addFile( $temp_php_file, $post_slug . '/plugin-file.php' );
				$zip->addFile( $temp_js_file, $post_slug . '/plugin-scripts.js' ); // Legacy name
				$zip->addFile( $temp_css_file, $post_slug . '/plugin-styles.css' ); // Legacy name
                
				// Logging results of addFile can be helpful
                // if (!$zip_result_js) error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to add JS file to zip: ' . $temp_js_file);
                // if (!$zip_result_css) error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to add CSS file to zip: ' . $temp_css_file);

				$zip_close_result = $zip->close();
				if ( $zip_close_result !== true ) {
					error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to close zip file. Error code: ' . $zip_close_result);
					$wp_filesystem->rmdir( $temp_plugin_path, true ); // Attempt cleanup
					wp_send_json_error( array( 'message' => 'error-zip-close' ) );
					wp_die();
				}

				// Cleanup temporary directory
				if ( ! $wp_filesystem->rmdir( $temp_plugin_path, true ) ) {
					error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to remove temp plugin folder: ' . $temp_plugin_path);
					// Not a fatal error for the user, as ZIP is created, but log it.
				}

				wp_send_json_success( $zip_url );
			} else {
				error_log('[Kairos WP Ajax DEBUG] Download ZIP - Failed to open zip file for creation: ' . $zip_path);
				$wp_filesystem->rmdir( $temp_plugin_path, true ); // Attempt cleanup
				wp_send_json_error( array( 'message' => 'error-zip-open' ) ); // Consistent error format
			}
		// Removed the initial broad isset check, individual checks for nonce and post_id are done at the top.
		// If we reach here, it implies nonce and post_id were present.
		// The code for php_code, js_code, css_code is fetched from meta, so no $_POST check needed for them here.

		wp_die();
	}

	public function kairos_wp_handle_edit() {
		if ( isset( $_POST['edited'], $_POST['type'], $_POST['post_id'] ) ) {
			if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' )
			|| ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

			$user = wp_get_current_user();
			if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ! in_array( 'administrator', $user->roles ) ) {
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

			$type    = sanitize_text_field( wp_unslash( $_POST['type'] ) );
			$post_id = intval( sanitize_text_field( wp_unslash( $_POST['post_id'] ) ) );

			if ( 'functional-requirements' !== $type ) {
				$edited = htmlspecialchars_decode( sanitize_textarea_field( esc_html( wp_unslash( $_POST['edited'] ) ) ), ENT_QUOTES );
				update_post_meta( $post_id, '_' . $type . '_output', $edited );
			} else {
				$edited = htmlspecialchars_decode( sanitize_text_field( esc_html( wp_unslash( $_POST['edited'] ) ) ), ENT_QUOTES );
				update_post_meta( $post_id, '_functional_requirements', $edited );
				update_post_meta( $post_id, '_code_not_generated', true );
			}

			wp_send_json_success( 'success-edit' );
		} else {
			wp_send_json_error( 'error-isset-post' );
		}

		wp_die();
	}

	// Obsolete functions related to direct DeepSeek API calls from PHP have been removed.
	// All AI interactions are now handled by Vercel Functions.

	public function kairos_wp_handle_undo_rephrase() {
		if ( isset( $_POST['functional_requirements'], $_POST['post_id'], $_POST['old_code_not_generated'] ) ) {
			if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['nonce'] ) ), 'kairos_wp_nonce' )
			|| ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

			$user = wp_get_current_user();
			if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ! in_array( 'administrator', $user->roles ) ) {
				wp_send_json_error( 'error-unauthorized-access' );
				wp_die();
			}

			$post_id                 = intval( sanitize_text_field( wp_unslash( $_POST['post_id'] ) ) );
			$functional_requirements = sanitize_textarea_field( wp_unslash( $_POST['functional_requirements'] ) );
			$old_code_not_generated  = sanitize_text_field( wp_unslash( $_POST['old_code_not_generated'] ) );

			update_post_meta( $post_id, '_functional_requirements', $functional_requirements );
			update_post_meta( $post_id, '_code_not_generated', ! empty( $old_code_not_generated ) ? true : false );
			wp_send_json_success( 'success-undo-rephrase' );
		} else {
			wp_send_json_error( 'error-isset-post' );
		}
		wp_die();
	}
}
