<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Kairos_WP_Core_Framework {
	// Add $hook_suffix parameter to match child class signature, even if not used here
	private function kairos_wp_enqueue_scripts( $hook_suffix = null ) {
		global $typenow;

		// Existing logic doesn't use $hook_suffix, but it's added for compatibility
		if ( 'kairos_wp' === $typenow ) {
			wp_enqueue_style( 'kairos-wp-style', plugin_dir_url( __DIR__ ) . 'css/style.css', array(), filemtime( plugin_dir_path( dirname( __DIR__ ) ) . 'framework/css/style.css' ) );
			wp_enqueue_script( 'kairos-wp-script', plugin_dir_url( dirname( __DIR__ ) ) . 'assets/js/script.js', array( 'jquery' ), filemtime( plugin_dir_path( dirname( __DIR__ ) ) . 'assets/js/script.js' ), true );
			wp_localize_script(
				'kairos-wp-script',
				'kairos_wp_object',
				array(
					'ajax_url'       => admin_url( 'admin-ajax.php' ),
					// 'api_key'        => get_option( 'kairos_wp_api_key', '' ), // Obsolete: API key managed by backend
					'link'           => admin_url( 'admin.php?page=kairos-wp-settings' ),
					'pluginMessages' => $this->get_kairos_wp_messages_localize(),
				)
			);
		}

		if ( ( isset( $_GET['page'] ) && 'kairos-wp-home' === $_GET['page'] ) || ( isset( $_GET['page'] ) && 'kairos-wp-settings' === $_GET['page'] ) ) {
			wp_enqueue_style( 'kairos-wp-style', plugin_dir_url( __DIR__ ) . 'css/style.css', array(), filemtime( plugin_dir_path( dirname( __DIR__ ) ) . 'framework/css/style.css' ) );
		}
	}

	// Add $hook_suffix parameter to the public wrapper as well
	public function get_kairos_wp_enqueue_scripts( $hook_suffix = null ) {
		$this->kairos_wp_enqueue_scripts( $hook_suffix );
	}

	private function kairos_wp_activate() {
		update_option( 'kairos_wp_activated', true );
	}

	public function get_kairos_wp_activate() {
		$this->kairos_wp_activate();
	}

	private function kairos_wp_redirect_after_activation() {
		if ( get_option( 'kairos_wp_activated', false ) ) {
			delete_option( 'kairos_wp_activated' );

			wp_safe_redirect( admin_url( 'admin.php?page=kairos-wp-home' ) );
			exit;
		}
	}

	public function get_kairos_wp_redirect_after_activation() {
		$this->kairos_wp_redirect_after_activation();
	}

	private function kairos_wp_normalize_array_structure( $array ) {
		if ( is_array( $array ) && count( $array ) === 1 && is_array( $array[0] ) ) {
			return $array[0];
		}
		return $array;
	}

	public function get_kairos_wp_normalize_array_structure( $array ) {
		return $this->kairos_wp_normalize_array_structure( $array );
	}

	private function kairos_wp_load_textdomain() {
		load_plugin_textdomain( 'kairos-wp', false, dirname( plugin_basename( dirname( __DIR__ ) ) ) . '/languages' );
	}

	public function get_kairos_wp_load_textdomain() {
		$this->kairos_wp_load_textdomain();
	}

	public function kairos_wp_messages_localize() {
		$messages_json = file_get_contents( plugin_dir_path( __DIR__ ) . 'json/messages.json' );
		$messages      = json_decode( $messages_json, true );

		foreach ( $messages as $code => $message ) {
			$messages[ $code ] = __( $message, 'kairos-wp' );
		}

		return $messages;
	}

	public function get_kairos_wp_messages_localize() {
		return $this->kairos_wp_messages_localize();
	}

	private function kairos_wp_extract_code( $data, $start_tag, $end_tag ) {
		$start_index = strpos( $data, $start_tag );

		if ( false !== $start_index ) {
			$start_offset = $start_index + strlen( $start_tag );
			// Find the *next* occurrence of the end tag *after* the start tag's content begins
			$end_index = strpos( $data, $end_tag, $start_offset );

			// If end tag is found, extract between start and end tags
			if ( false !== $end_index ) {
				$code = substr( $data, $start_offset, $end_index - $start_offset );
			} else {
				// If end tag is NOT found, extract from start tag to the end of the string
				// This handles cases where the AI might omit the closing tag for ANY block type
				$code = substr( $data, $start_offset );
				// Log this fallback case for debugging, as it might indicate an incomplete response
				error_log('[Kairos WP Debug - Core Framework] Extracted code assuming missing end tag (' . $end_tag . ') for start tag: ' . $start_tag);
			}

			// Trim whitespace and potentially remove leading/trailing newlines common in AI responses
			$code = trim( $code );
			return $code;
		}

		// Start tag not found
		return '';
	}

	public function get_kairos_wp_extract_code( $data, $start_tag, $end_tag ) {
		return $this->kairos_wp_extract_code( $data, $start_tag, $end_tag );
	}

	private function kairos_wp_array_flatten( $input ) {
		$result = array();

		if ( is_array( $input ) ) {
			foreach ( $input as $item ) {
				if ( is_array( $item ) ) {
					$result = array_merge( $result, $this->get_kairos_wp_array_flatten( $item ) );
				} elseif ( is_string( $item ) ) {
					$result[] = $item;
				}
			}
		} elseif ( is_string( $input ) ) {
			$result[] = $input;
		}

		return $result;
	}

	public function get_kairos_wp_array_flatten( $input ) {
		return $this->kairos_wp_array_flatten( $input );
	}

}
