<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-render-framework.php';

class Kairos_WP_Post_Type_Framework {
	public $render;

	public function __construct() {
		$this->render = new Kairos_WP_Render_Framework();
	}

	private function kairos_wp_register_post_type() {
		$args = array(
			'labels'        => array(
				'name'               => esc_html__( 'Kairos Plugins', 'kairos-wp' ),
				'singular_name'      => esc_html__( 'Kairos Plugin', 'kairos-wp' ),
				'add_new_item'       => esc_html__( 'New Kairos Plugin', 'kairos-wp' ),
				'add_new'            => esc_html__( 'Add New Kairos Plugin', 'kairos-wp' ),
				'edit_item'          => esc_html__( 'Edit Kairos Plugin', 'kairos-wp' ),
				'menu_name'          => esc_html__( 'Kairos WP', 'kairos-wp' ),
				'search_items'       => esc_html__( 'Search Kairos Plugins', 'kairos-wp' ),
				'not_found'          => esc_html__( 'No Kairos Plugins found.', 'kairos-wp' ),
				'not_found_in_trash' => esc_html__( 'No Kairos Plugins found in Trash.', 'kairos-wp' ),
				'view_item'          => esc_html__( 'View Kairos Plugin', 'kairos-wp' ),
			),
			'public'        => false,
			'show_ui'       => true,
			'show_in_menu'  => false,
			'menu_position' => 3,
			'menu_icon'     => 'dashicons-lightbulb',
			'supports'      => array( 'title', 'revisions' ),
		);

		register_post_type( 'kairos_wp', $args );
	}

	public function get_kairos_wp_register_post_type() {
		$this->kairos_wp_register_post_type();
	}

	private function kairos_wp_hide_posts_for_non_admins( $query ) {
		$user = wp_get_current_user();
		if ( 'kairos_wp' === $query->get( 'post_type' ) && $query->is_main_query() && ! in_array( 'administrator', $user->roles ) ) {
			wp_die('<div class="wp-die-message"><h1>Unauthorized access!</h1><p>Only Administrators are allowed to use Kairos WP plugin. If you think this is an error, please contact your Administrator.</p></div>');
		}
	}

	public function get_kairos_wp_hide_posts_for_non_admins( $query ) {
		$this->kairos_wp_hide_posts_for_non_admins( $query );
	}

	private function kairos_wp_restrict_post_access() {
		global $pagenow;
		if ( 'post.php' === $pagenow ) {
			$post_id   = isset( $_GET['post'] ) ? intval( $_GET['post'] ) : 0;
			$post_type = get_post_type( $post_id );
			$user      = wp_get_current_user();
			if ( 'kairos_wp' === $post_type && ! in_array( 'administrator', $user->roles ) ) {
			}
		}
	}

	public function get_kairos_wp_restrict_post_access() {
		$this->kairos_wp_restrict_post_access();
	}

	private function kairos_wp_add_output_meta_boxes() {
		// Add the new Token Economy metabox
		add_meta_box(
			'kairos-wp-token-economy-meta-box', // Unique ID for the metabox
			esc_html__( 'Token Economy', 'kairos-wp' ), // Title of the metabox
			array( $this->render, 'get_kairos_wp_render_token_economy_metabox' ), // Callback function in Render class to display content
			'kairos_wp', // Post type slug
			'side', // Context (normal, side, advanced)
			'high' // Priority (high, core, default, low)
		);

		// Metaboxes for individual code types (PHP, JS, CSS), download, and old confidence
		// were removed as their functionality is now integrated into the main agent UI,
		// which is rendered via the 'edit_form_after_title' hook.
	}

	public function get_kairos_wp_add_output_meta_boxes() {
		$this->kairos_wp_add_output_meta_boxes();
	}

	private function kairos_wp_add_menu_pages() {
		add_menu_page(
			esc_html__( 'Kairos WP', 'kairos-wp' ),
			esc_html__( 'Kairos WP', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-home',
			array( $this->render, 'get_kairos_wp_render_home_page' ),
			'dashicons-lightbulb',
			3
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Home', 'kairos-wp' ),
			esc_html__( 'Home', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-home',
			array( $this->render, 'get_kairos_wp_render_home_page' )
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Plugins', 'kairos-wp' ),
			esc_html__( 'Kairos Plugins', 'kairos-wp' ),
			'manage_options',
			'edit.php?post_type=kairos_wp'
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Add New Kairos Plugin', 'kairos-wp' ),
			esc_html__( 'Add New Kairos Plugin', 'kairos-wp' ),
			'manage_options',
			'post-new.php?post_type=kairos_wp'
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Settings', 'kairos-wp' ),
			esc_html__( 'Settings', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-settings',
			array( $this->render, 'get_kairos_wp_render_settings_page' )
		);

		// Add Documentation Submenu Page
		add_submenu_page(
			'kairos-wp-home', // Parent slug
			esc_html__( 'Kairos Documentation', 'kairos-wp' ), // Page title
			esc_html__( 'Documentation', 'kairos-wp' ), // Menu title
			'manage_options', // Capability
			'kairos-wp-documentation', // Menu slug
			array( $this->render, 'get_kairos_wp_render_documentation_page' ) // Callback function in Render class
		);
	}

	public function get_kairos_wp_add_menu_pages() {
		$this->kairos_wp_add_menu_pages();
	}

	private function kairos_wp_highlight_submenu() {
		global $parent_file, $submenu_file, $post_type;

		if ( 'kairos_wp' === $post_type ) {
			$parent_file  = 'kairos-wp-home';
			$submenu_file = 'edit.php?post_type=kairos_wp';
		} elseif ( isset( $_GET['page'] ) && 'kairos-wp-settings' === $_GET['page'] ) {
			$parent_file  = 'kairos-wp-home';
			$submenu_file = 'kairos-wp-settings';
		} elseif ( isset( $_GET['page'] ) && 'kairos-wp-documentation' === $_GET['page'] ) { // Highlight Documentation submenu
			$parent_file  = 'kairos-wp-home';
			$submenu_file = 'kairos-wp-documentation';
		}
	}

	public function get_kairos_wp_highlight_submenu() {
		$this->kairos_wp_highlight_submenu();
	}

	private function kairos_wp_register_settings() {
		add_settings_section(
			'kairos_wp_section',
			esc_html__( 'Kairos Settings', 'kairos-wp' ),
			null,
 			'kairos_wp_settings'
 		);
 		// --- FIN: Registro del ajuste para hCaptcha Sitekey ---

 		// --- API Configuration Fields Removed ---

 		// REMOVED: Model Selection fields (Developer, Consultant)

		// Register all settings (API related settings removed)
		// Note: Child class might register other settings if needed.
	}


	public function get_kairos_wp_register_settings() {
		$this->kairos_wp_register_settings();
	}

	private function kairos_wp_enable_meta_revisions( $revisioned_keys ) {
		if ( ! in_array( '_post_slug', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_post_slug';
		}
		if ( ! in_array( '_improvements', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_improvements';
		}
		if ( ! in_array( '_php_output', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_php_output';
		}
		if ( ! in_array( '_js_output', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_js_output';
		}
		if ( ! in_array( '_css_output', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_css_output';
		}
		if ( ! in_array( '_functional_requirements', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_functional_requirements';
		}
		return $revisioned_keys;
	}

	public function get_kairos_wp_enable_meta_revisions( $revisioned_keys ) {
		return $this->kairos_wp_enable_meta_revisions( $revisioned_keys );
	}

	private function kairos_wp_enable_meta_revision_fields( $fields ) {
		$fields['_post_slug']                    = esc_html__( 'Post Slug', 'kairos-wp' );
		$fields['_improvements']                 = esc_html__( 'Improvements', 'kairos-wp' );
		$fields['_functional_requirements']      = esc_html__( 'Functional Requirements', 'kairos-wp' );
		$fields['_php_output']                   = esc_html__( 'PHP Output', 'kairos-wp' );
		$fields['_js_output']                    = esc_html__( 'JS Output', 'kairos-wp' );
		$fields['_css_output']                   = esc_html__( 'CSS Output', 'kairos-wp' );
		return $fields;
	}

	public function get_kairos_wp_enable_meta_revision_fields( $fields ) {
		return $this->kairos_wp_enable_meta_revision_fields( $fields );
	}

	private function kairos_wp_change_title_placeholder( $title, $post ) {
		if ( 'kairos_wp' === $post->post_type ) {
			$title = esc_html__( 'Add Plugin Title', 'kairos-wp' );
		}
		return $title;
	}

	public function get_kairos_wp_change_title_placeholder( $title, $post ) {
		return $this->kairos_wp_change_title_placeholder( $title, $post );
	}
}
