<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Get avatar URLs relative to this view file's directory URL
$view_dir_url = plugin_dir_url( __FILE__ );
$lola_avatar_url = $view_dir_url . '../../assets/images/avatars/lola_avatar.png';
$pablo_avatar_url = $view_dir_url . '../../assets/images/avatars/pablo_avatar.png';
$alex_avatar_url = $view_dir_url . '../../assets/images/avatars/alex_avatar.png';

?>
<div class="wrap kairos-wp-welcome-wrapper kairos-wp-sales-style"> <?php // Added wrap class and new style class ?>

	<div class="kairos-wp-hero">
		<h1><?php echo esc_html__( 'Stop Dreaming About Custom Plugins. Let Your AI Team Build Them!', 'kairos-wp' ); ?></h1>
		<p class="kairos-wp-subtitle"><?php echo esc_html__( 'Kairos WP brings together a dedicated team of AI agents – Consultant, Developer, and Reviewer – to turn your ideas into functional WordPress plugins in minutes, no coding required!', 'kairos-wp' ); ?></p>
		<div class="kairos-wp-cta-main">
			<a class="button button-primary button-hero" href="<?php echo esc_url( admin_url( 'post-new.php?post_type=kairos_wp' ) ); ?>"><?php echo esc_html__( 'Start Building Your Plugin Now!', 'kairos-wp' ); ?></a>
		</div>
	</div>

	<div class="kairos-wp-section">
		<h2><?php echo esc_html__( 'Meet Your Expert AI Development Team', 'kairos-wp' ); ?></h2>
		<p class="kairos-wp-section-intro"><?php echo esc_html__( 'Why hire developers when you have AI experts ready to work for you 24/7?', 'kairos-wp' ); ?></p>

		<div class="kairos-wp-agents-intro">
			<div class="kairos-wp-agent-intro-card">
				<img src="<?php echo esc_url($lola_avatar_url); ?>" alt="<?php esc_attr_e( 'Lola Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-intro-avatar">
				<h3><?php echo esc_html__( 'Lola: Your Strategic Consultant', 'kairos-wp' ); ?></h3>
				<p><?php echo esc_html__( 'Lola transforms your vision into a clear blueprint (PRD), ensuring Pablo knows exactly what to build.', 'kairos-wp' ); ?></p>
			</div>
			<div class="kairos-wp-agent-intro-card">
				<img src="<?php echo esc_url($pablo_avatar_url); ?>" alt="<?php esc_attr_e( 'Pablo Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-intro-avatar">
				<h3><?php echo esc_html__( 'Pablo: Your Dedicated Developer', 'kairos-wp' ); ?></h3>
				<p><?php echo esc_html__( 'Pablo writes the PHP, JavaScript, and CSS code, bringing your plugin to life based on Lola\'s precise requirements.', 'kairos-wp' ); ?></p>
			</div>
			<div class="kairos-wp-agent-intro-card">
				<img src="<?php echo esc_url($alex_avatar_url); ?>" alt="<?php esc_attr_e( 'Alex Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-intro-avatar">
				<h3><?php echo esc_html__( 'Alex: Your Quality Assurance', 'kairos-wp' ); ?></h3>
				<p><?php echo esc_html__( 'Alex meticulously reviews Pablo\'s code, providing confidence scores and actionable suggestions for peak performance.', 'kairos-wp' ); ?></p>
			</div>
		</div>
	</div>

	<div class="kairos-wp-section kairos-wp-resources">
		<h2><?php echo esc_html__( 'Need Help?', 'kairos-wp' ); ?></h2>
		<p>
			<a class="button button-secondary" href="https://vanguardhive.com/kairoswp" target="_blank" rel="noopener noreferrer"><?php echo esc_html__( 'Official Website', 'kairos-wp' ); ?></a>
			<a class="button button-secondary" href="<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-documentation' ) ); ?>"><?php echo esc_html__( 'Documentation', 'kairos-wp' ); ?></a> <?php // Updated Documentation URL ?>
			<a class="button button-secondary" href="mailto:contacto@vanguardhive.com"><?php echo esc_html__( 'Contact Support', 'kairos-wp' ); ?></a> <?php // Updated Support URL and Text ?>
		</p>
	</div>

	<?php // Add some basic styling for the new elements ?>
	<style>
		.kairos-wp-sales-style h1 {
			font-size: 2.5em; /* Larger H1 */
			color: #2c3e50;
			text-align: center;
			margin-bottom: 0.5em;
            line-height: 1.2;
		}
        .kairos-wp-sales-style h2 {
            font-size: 1.8em; /* Larger H2 */
            color: #34495e;
            text-align: center;
            margin-top: 1.5em;
            margin-bottom: 0.8em;
        }
        .kairos-wp-sales-style h3 {
             font-size: 1.2em; /* Slightly larger H3 */
        }
        .kairos-wp-hero {
            text-align: center;
            padding: 2em 1em;
            background-color: #f8f9fa; /* Light background for hero */
            border-radius: 5px;
            margin-bottom: 2em;
        }
        .kairos-wp-subtitle {
            font-size: 1.2em;
            color: #555;
            max-width: 800px;
            margin: 0 auto 1.5em auto;
        }
        .kairos-wp-cta-main .button-hero {
            padding: 12px 25px;
            font-size: 1.1em;
        }
        .kairos-wp-section {
            margin-bottom: 3em;
            padding: 1.5em;
            background-color: #fff;
            border: 1px solid #e5e5e5;
            border-radius: 4px;
        }
        .kairos-wp-section-intro {
            text-align: center;
            font-size: 1.1em;
            color: #666;
            margin-bottom: 2em;
            max-width: 700px;
            margin-left: auto;
            margin-right: auto;
        }
		.kairos-wp-agents-intro {
			display: flex;
			gap: 25px; /* Increased gap */
			margin-top: 1.5em;
			margin-bottom: 1em;
			flex-wrap: wrap;
    		justify-content: center;
		}
		.kairos-wp-agent-intro-card {
			flex: 1;
			min-width: 260px; /* Slightly larger min-width */
    		max-width: 310px;
			padding: 25px; /* Increased padding */
			border: 1px solid #ccd0d4;
			border-radius: 4px;
			text-align: center;
			background-color: #fff;
			box-shadow: 0 2px 4px rgba(0,0,0,.08); /* Slightly stronger shadow */
            transition: transform 0.2s ease-in-out;
		}
        .kairos-wp-agent-intro-card:hover {
            transform: translateY(-5px); /* Add hover effect */
        }
		.kairos-wp-agent-intro-avatar {
			width: 90px; /* Larger avatar */
			height: 90px;
			border-radius: 50%;
			margin-bottom: 1em;
			border: 3px solid #f0f0f1; /* Slightly thicker border */
		}
		.kairos-wp-agent-intro-card h3 {
			margin-top: 0;
			margin-bottom: 0.5em;
			color: #2c3e50;
		}
		.kairos-wp-agent-intro-card p {
			font-size: 0.95em;
			color: #50575e;
			margin-bottom: 0;
            line-height: 1.5;
		}
        .kairos-wp-get-started,
        .kairos-wp-resources {
            text-align: center;
        }
        .kairos-wp-welcome-tools a,
        .kairos-wp-resources p a {
            margin: 8px; /* Increased spacing */
        }
        .kairos-wp-resources {
            background-color: #f8f9fa; /* Different background for resources */
            border-top: 2px solid #e0e0e0;
        }
	</style>

</div> <?php // End wrap ?>
