<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __DIR__ ) . '/framework/includes/class-kairos-wp-core-framework.php'; // Will be renamed later
require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-ajax.php'; // Include the AJAX class

class Kairos_WP_Core extends Kairos_WP_Core_Framework { // Renamed class and parent

	// REMOVED LEGACY FUNCTION: kairos_wp_save_generate() and its public wrapper get_kairos_wp_save_generate()

    public function __construct() {
        // Add the action hook for registering AJAX handlers
        add_action( 'init', array( $this, 'register_ajax_handlers' ) );
        // Add other init actions like rewrite rules
        add_action( 'init', array( $this, 'get_kairos_wp_register_rewrites' ) );
        // Add action for template redirect
		add_action( 'template_redirect', array( $this, 'get_kairos_wp_template_redirect_handler' ) );
        // Add action for enqueueing scripts
        add_action( 'admin_enqueue_scripts', array( $this, 'get_kairos_wp_enqueue_scripts' ) );
         // Add action for loading text domain
        add_action( 'plugins_loaded', array( $this, 'get_kairos_wp_load_textdomain' ) );

        // Activation hook needs to be registered statically in the main plugin file
        // register_activation_hook( __FILE__, array( $this, 'get_kairos_wp_activate' ) );
    }

    /**
     * Register AJAX handlers.
     */
    public function register_ajax_handlers() {
        $ajax_handler = new Kairos_WP_Ajax();

        // New specific handlers
        add_action( 'wp_ajax_kairos_wp_save_initial_lola', array( $ajax_handler, 'kairos_wp_handle_save_initial_lola' ) );
        add_action( 'wp_ajax_kairos_wp_save_pablo_results', array( $ajax_handler, 'kairos_wp_handle_save_pablo_results' ) );
        add_action( 'wp_ajax_kairos_wp_save_alex_review', array( $ajax_handler, 'kairos_wp_handle_save_alex_review' ) );
        add_action( 'wp_ajax_kairos_wp_save_refined_lola', array( $ajax_handler, 'kairos_wp_handle_save_refined_lola' ) );
        add_action( 'wp_ajax_kairos_wp_save_manual_edit', array( $ajax_handler, 'kairos_wp_handle_save_manual_edit' ) );

        // Existing handlers (ensure they are registered if not handled by framework)
        add_action( 'wp_ajax_kairos_wp_save_to_plugins', array( $ajax_handler, 'kairos_wp_handle_save_to_plugins' ) );
        add_action( 'wp_ajax_kairos_wp_mark_as_finished', array( $ajax_handler, 'kairos_wp_handle_mark_as_finished' ) );

        // --- ADDED: Register Get Token Quota Proxy Handler ---
        add_action( 'wp_ajax_kairos_wp_get_token_quota_proxy', array( $ajax_handler, 'kairos_wp_get_token_quota_proxy' ) );

    }


	// Enqueue scripts and styles based on the current admin page
	private function kairos_wp_enqueue_scripts( $hook_suffix = null ) {
		global $post_type, $pagenow;

		$plugin_main_file = plugin_dir_path( dirname( __FILE__ ) ) . 'kairos-wp-developer-init.php';
		// Get plugin version from the main file header
		$plugin_data = get_plugin_data( $plugin_main_file );
		$plugin_version = isset( $plugin_data['Version'] ) ? $plugin_data['Version'] : time(); // Fallback to time() if version not found

		$js_modules_path = dirname(__DIR__) . '/assets/js/modules/';
		$js_modules_url = plugins_url( 'assets/js/modules/', $plugin_main_file );

		// --- Register All JS Modules ---
		// Use the defined plugin version for cache busting
		wp_register_script( 'kairos-wp-utils', $js_modules_url . '_utils.js', array('jquery'), $plugin_version, true );
		// Use filemtime for _ui-helpers.js
		$ui_helpers_js_path = $js_modules_path . '_ui-helpers.js';
		$ui_helpers_js_version = file_exists($ui_helpers_js_path) ? filemtime($ui_helpers_js_path) : $plugin_version;
		wp_register_script( 'kairos-wp-ui-helpers', $js_modules_url . '_ui-helpers.js', array('jquery', 'thickbox', 'kairos-wp-utils'), $ui_helpers_js_version, true );
		wp_register_script( 'kairos-wp-api-calls', $js_modules_url . '_api-calls.js', array('jquery', 'kairos-wp-utils'), $plugin_version, true );
		wp_register_script( 'kairos-wp-auth', $js_modules_url . '_auth.js', array('jquery', 'kairos-wp-api-calls', 'kairos-wp-utils'), $plugin_version, true );
		// Use filemtime for more robust cache busting for the settings page script
		$settings_js_path = $js_modules_path . '_settings-page.js';
		$settings_js_version = file_exists($settings_js_path) ? filemtime($settings_js_path) : $plugin_version;
		wp_register_script( 'kairos-wp-settings', $js_modules_url . '_settings-page.js', array('jquery', 'kairos-wp-auth', 'kairos-wp-utils'), $settings_js_version, true );
		wp_register_script( 'kairos-wp-cpt', $js_modules_url . '_cpt-screen.js', array('jquery', 'kairos-wp-auth', 'kairos-wp-api-calls', 'kairos-wp-ui-helpers', 'kairos-wp-utils'), $plugin_version, true );


		// --- Common Data for Localization ---
		// Localize common data to the base utility script so it's available early for dependencies
		$common_script_data = array(
			'ajax_url'       => admin_url( 'admin-ajax.php' ),
			'pluginMessages' => $this->get_kairos_wp_plugin_messages(),
			'link'           => admin_url( 'admin.php?page=kairos_wp_settings' ),
			'plugin_url'     => plugin_dir_url( $plugin_main_file ),
			'nonce'          => wp_create_nonce( 'kairos_wp_nonce' ), // Generate nonce here
			'site_url'       => home_url() // Add the site URL here
		);
		wp_localize_script( 'kairos-wp-utils', 'kairos_wp_object', $common_script_data ); // Localize to base script

		// --- Enqueue Styles (Common for now) ---
		// Consider conditional loading if styles become very page-specific
		$css_path = dirname(__DIR__) . '/framework/css/style.css';
		$css_url = plugins_url( 'framework/css/style.css', $plugin_main_file );
		if (file_exists($css_path)) {
			wp_enqueue_style( 'kairos-wp-style', $css_url, array(), filemtime( $css_path ) );
		} else {
			error_log("[Kairos WP Debug - Enqueue] Main Style File Missing: " . $css_path);
		}

		// --- Conditional Script Enqueuing ---

		// 0. Kairos WP Home Page (toplevel_page_kairos-wp-home)
		// Enqueue scripts needed for auth check and potential redirection.
		if ( $hook_suffix === 'toplevel_page_kairos-wp-home' ) {
			wp_enqueue_script( 'kairos-wp-utils' ); // For kairos_wp_get_message if used by other scripts
			wp_enqueue_script( 'kairos-wp-api-calls' ); // For verifyToken
			// No specific script for home page logic yet, will be inline in Kairos_WP_Render
			// Localize common data if not already done by utils dependency chain
			wp_localize_script( 'kairos-wp-utils', 'kairos_wp_object', $common_script_data );
		}

		// 1. CPT Edit Screen ('kairos_wp')
		if ( ( 'post.php' === $pagenow || 'post-new.php' === $pagenow ) && isset( $post_type ) && 'kairos_wp' === $post_type ) {

			// Enqueue ThickBox for modals used on this screen
			add_thickbox();

			// Enqueue UI Helpers explicitly (as a contingency) and the main CPT script
			wp_enqueue_script( 'kairos-wp-ui-helpers' ); // Explicitly enqueue UI helpers
			wp_enqueue_script( 'kairos-wp-cpt' ); // Dependencies (including ui-helpers) should still work, but this adds redundancy

			// Localize data specifically for the CPT script, including common data + token meta
			// This will overwrite the object localized to 'kairos-wp-utils' on this specific page,
			// ensuring the CPT script has access to everything it needs.
			$cpt_script_data = $common_script_data; // Start with common data
			if (isset($_GET['post'])) {
				$post_id = intval($_GET['post']);
				$cpt_script_data['token_meta'] = array(
					'lola_initial' => get_post_meta($post_id, '_lola_initial_total_tokens', true) ?: 0,
					'lola_refine'  => get_post_meta($post_id, '_lola_refine_total_tokens', true) ?: 0,
					'pablo'        => get_post_meta($post_id, '_pablo_total_tokens', true) ?: 0,
					'alex'         => get_post_meta($post_id, '_alex_total_tokens', true) ?: 0,
					'cumulative'   => get_post_meta($post_id, '_total_tokens_cumulative', true) ?: 0,
				);
			} else {
				$cpt_script_data['token_meta'] = array( // Default for new posts
					'lola_initial' => 0, 'lola_refine' => 0, 'pablo' => 0, 'alex' => 0, 'cumulative' => 0,
				);
			}
			// Localize the combined data (common + token_meta) to the CPT script handle
			wp_localize_script( 'kairos-wp-cpt', 'kairos_wp_object', $cpt_script_data );
		}

		// 2. Settings Page
		// Determine the correct hook suffix for the settings page
		// For a submenu page under a custom top-level menu, the hook is [parent_slug]_page_[submenu_slug]
		$settings_page_hook = 'kairos-wp_page_kairos-wp-settings'; // Correct hook for submenu page
		if ( $hook_suffix === $settings_page_hook ) {

			// Enqueue the main settings script (dependencies will load automatically)
			wp_enqueue_script( 'kairos-wp-settings' );

			// Localize common data specifically for the settings script handle as well.
 			// Although localized to utils, this ensures kairos_wp_object is directly available
 			// for this specific script handle on this page.
 			// wp_localize_script( 'kairos-wp-settings', 'kairos_wp_object', $common_script_data ); // Moved localization below

			// --- AÑADIR: Carga de hCaptcha y localización de sitekey ---
			// Cargar el script de la API de hCaptcha de forma asíncrona
			wp_enqueue_script( 'hcaptcha-api', 'https://js.hcaptcha.com/1/api.js', array(), null, true ); // El último true lo pone en el footer
			// Añadir atributos async y defer (WordPress 5.5+)
			// Usamos una función anónima para evitar conflictos si se usa en otro lugar
			add_filter( 'script_loader_tag', function( $tag, $handle, $src ) {
				if ( 'hcaptcha-api' === $handle ) {
					// Buscar la etiqueta script y añadir async defer
					if ( false === stripos( $tag, 'async' ) ) {
						$tag = str_replace( ' src', ' async="async" src', $tag );
					}
					if ( false === stripos( $tag, 'defer' ) ) {
						$tag = str_replace( ' src', ' defer="defer" src', $tag );
					}
				}
				return $tag;
 			}, 10, 3 );

 			// --- FIN: Carga de hCaptcha ---

 			// Volvemos a localizar aquí específicamente para 'kairos-wp-settings' por si acaso.
 			// Esto asegura que el objeto esté directamente disponible para este script en esta página.
 			wp_localize_script( 'kairos-wp-settings', 'kairos_wp_object', $common_script_data );
 		}
 	}

	// Public wrapper - Keep signature consistent
	public function get_kairos_wp_enqueue_scripts( $hook_suffix = null ) {
		$this->kairos_wp_enqueue_scripts( $hook_suffix );
	}

	// Define plugin messages for JS - Keep only one declaration (private)
	private function get_kairos_wp_plugin_messages() { // Renamed function
		// Use __() here because the values are passed to JS via wp_localize_script,
		// which handles escaping. esc_html__() would double-escape.
		return array(
			'error-general'                     => __( 'An unexpected error occurred. Please try again.', 'kairos-wp' ),
			'error-no-title'                    => __( 'Please enter a title for your plugin.', 'kairos-wp' ),
			'error-no-api-key'                  => __( 'Kairos AI API key is missing. Please configure it in the settings.', 'kairos-wp' ),
			'error-empty-initial-prompt'        => __( 'Please describe your plugin idea first.', 'kairos-wp' ),
			'error-empty-requirements'          => __( 'Functional requirements cannot be empty.', 'kairos-wp' ),
			'error-empty-improvements'          => __( 'Please describe the improvements before sending.', 'kairos-wp' ),
			'error-empty-edit'                  => __( 'Edited content cannot be empty.', 'kairos-wp' ),
			'error-empty-copy'                  => __( 'There is no code to copy.', 'kairos-wp' ),
			'error-no-code-to-test'             => __( 'No code generated yet to test.', 'kairos-wp' ),
			'error-empty-code-view'             => __( 'No code available to view for this type.', 'kairos-wp' ),
			'error-no-suggestions-selected'     => __( 'Please select at least one suggestion to apply.', 'kairos-wp' ),
			'error-api-unable-to-connect'       => __( 'Unable to connect to the AI API. Please check your connection or API key.', 'kairos-wp' ),
			'error-api'                         => __( 'An error occurred with the AI API:', 'kairos-wp' ), // Append specific message in JS
			'error-api-invalid-response'        => __( 'Received an invalid response from the AI API.', 'kairos-wp' ),
			'error-unauthorized-access'         => __( 'Unauthorized access attempt.', 'kairos-wp' ),
			'error-isset-post'                  => __( 'Missing necessary data. Please try again.', 'kairos-wp' ),
			'error-save-multisite'              => __( 'Sorry, I cannot save directly to the plugins folder in multisite installations.', 'kairos-wp' ),
			'error-save-loopback'               => __( 'Oops! WordPress could not perform an internal test to check for fatal errors. I have not saved the plugin to avoid issues.', 'kairos-wp' ),
			'loading'                           => __( 'Loading...', 'kairos-wp' ), // Added missing key
			'error'                             => __( 'Error', 'kairos-wp' ), // Added generic error key
			'Review pending or explanation not available.' => __( 'Review pending or explanation not available.', 'kairos-wp' ), // Added missing key
			'error-save-php'                    => __( 'The PHP code I generated seems to have errors and I have not saved it:', 'kairos-wp' ), // Append specific error in JS
			'success-copy'                      => __( 'Code copied to clipboard!', 'kairos-wp' ),
			'success-save'                      => __( 'I have saved your plugin correctly!', 'kairos-wp' ),
			'success-rephrase'                  => __( 'Requirements updated!', 'kairos-wp' ), // Might not be shown directly
			'notice-refresh-after-api-key'      => __( 'It seems you have updated the API key. Please refresh the page so I can use it.', 'kairos-wp' ),
			'edit-requirements-title'           => __( 'Edit Functional Requirements', 'kairos-wp' ),
			'copied'                            => __( 'Copied!', 'kairos-wp' ),
			'copy-code'                         => __( 'Copy Code', 'kairos-wp' ),
			// Humanized Loader Messages
			'pablo-generating-php'              => __( 'I\'m Pablo! I\'m writing the PHP code for your plugin...', 'kairos-wp' ),
			'pablo-generating-js'               => __( 'I\'m Pablo! Now I\'m working on the JavaScript...', 'kairos-wp' ),
			'pablo-generating-css'              => __( 'I\'m Pablo! Adding the finishing touches with CSS...', 'kairos-wp' ),
			'pablo-generating-plugin-friendly'  => __( 'Hi, I\'m Pablo. I\'m developing your plugin, coding PHP, JS, and CSS. Please don\'t refresh the page or close this pop-up.', 'kairos-wp' ),
			'pablo-compiling'                   => __( 'Pablo is compiling the plugin...', 'kairos-wp' ),
			'alex-reviewing'                    => __( 'I\'m Alex! Give me a moment, I\'m reviewing the code...', 'kairos-wp' ),
            'lola-processing-initial-idea'      => __( 'Great! I\'m now refining your idea. Please wait...', 'kairos-wp' ),
            'lola-processing-improvements'      => __( 'Perfect, I\'m refining the change request. Give me a moment...', 'kairos-wp' ),
            'system-publishing-data'            => __( 'Publishing plugin data before generation. Please wait...', 'kairos-wp' ), 
			// Added missing messages from console log (v2)
			'Lola (Initial)'                    => __( 'Lola (Initial)', 'kairos-wp' ),
			'Lola (Refine)'                     => __( 'Lola (Refine)', 'kairos-wp' ),
			'Pablo (Generate)'                  => __( 'Pablo (Generate)', 'kairos-wp' ),
			'Alex (Review)'                     => __( 'Alex (Review)', 'kairos-wp' ),
			'Confidence Level:'                 => __( 'Confidence Level:', 'kairos-wp' ),
			'N/A'                               => __( 'N/A', 'kairos-wp' ),
			'Total Consumed:'                   => __( 'Total Consumed: %s', 'kairos-wp' ), // Added %s for sprintf replacement
			'No explanation provided.'          => __( 'No explanation provided.', 'kairos-wp' ),
			'No specific suggestions were provided.' => __( 'No specific suggestions were provided.', 'kairos-wp' ),
			// Added messages from the first 'undefined' errors in the log
			'label-after'                       => __( 'Request Changes or Improvements', 'kairos-wp' ), // Assuming this was one
			'label-after-description'           => __( 'Describe the changes you want to make to the generated plugin.', 'kairos-wp' ), // Assuming this was one
			'placeholder-improvements'          => __( 'Describe the desired improvements...', 'kairos-wp' ), // Assuming this was one
			// Stripe Messages
			'success-payment'                   => __( 'Payment successful! Your token balance will be updated shortly.', 'kairos-wp' ),
			'error-payment-cancelled'           => __( 'Payment process was cancelled.', 'kairos-wp' ),
			'error_auth_verify_failed_js'       => __( 'Error: Credentials cannot be verified. Try reloading the page or contact support.', 'kairos-wp' ),
			'error-thickbox-unavailable'        => __( 'Error: ThickBox is not available.', 'kairos-wp' ),
			'confirm-mark-as-finished'          => __( 'Are you sure you want to mark this plugin as completed? This will change its status to Published.', 'kairos-wp' ),
			'error-compile-unexpected-response' => __( 'Unexpected server response when compiling the plugin.', 'kairos-wp' ),
			'error-review-unexpected-response'  => __( 'Unexpected server response when reviewing the plugin.', 'kairos-wp' ),
			// Messages for _cpt-screen.js (from _auth.js section, some might be duplicates if used elsewhere)
			'error-api-functions-not-loaded'    => __( 'Error: API functions not loaded correctly.', 'kairos-wp' ),
			'error-lola-unexpected-response'    => __( 'Unexpected server response from Lola.', 'kairos-wp' ),
			'success-plugin-marked-completed-inline' => __( 'Plugin marked as completed!', 'kairos-wp' ),
			'button-completed'                  => __( 'Completed', 'kairos-wp' ),
			// Messages for _settings-page.js
			'quota-consumed-prefix'             => __( 'Consumed: ', 'kairos-wp' ),
			'quota-no-active'                   => __( 'No active quota', 'kairos-wp' ),
			'error-profile-not-found'           => __( 'Error: User profile not found.', 'kairos-wp' ),
			'error-session-expired'             => __( 'Session expired. Please log in again.', 'kairos-wp' ),
			'error-login-required-purchase'     => __( 'Please log in to purchase.', 'kairos-wp' ),
			'error-session-verification-failed' => __( 'Could not verify user session. Please log out and log back in.', 'kairos-wp' ),
			'error-user-identification-failed'  => __( 'Could not identify user. Please log out and log back in.', 'kairos-wp' ),
			'error-payment-link-missing'        => __( 'Configuration error: Payment link missing.', 'kairos-wp' ),
			// Messages for class-kairos-wp.php (Error handling for render methods)
			'error-render-class-not-found'      => __( 'Error: Render class not found.', 'kairos-wp' ),
			'error-initial-lola-render-method-not-found' => __( 'Error: Initial Lola screen render method not found.', 'kairos-wp' ),
			'error-refined-lola-render-method-not-found' => __( 'Error: Refined Lola screen render method not found.', 'kairos-wp' ),
			'error-delivery-render-method-not-found' => __( 'Error: Delivery screen render method not found.', 'kairos-wp' ),
			'error-popups-render-method-not-found' => __( 'Error: Popups render method not found.', 'kairos-wp' ),
			// Messages for _auth.js
			'error-login-empty-fields'          => __( 'Please enter email and password.', 'kairos-wp' ),
			'error-internal-api-config'         => __( 'Internal error (API Configuration).', 'kairos-wp' ),
			'success-login'                     => __( 'Login successful.', 'kairos-wp' ),
			'error-login-unknown'               => __( 'Unknown login error.', 'kairos-wp' ),
			'error-login-email-not-verified'    => __( 'Login failed: Your email address has not been verified. Please check your inbox (and spam folder) for the verification email we sent you and click the link to activate your account.', 'kairos-wp' ),
			'error-login-invalid-credentials'   => __( 'Invalid email or password.', 'kairos-wp' ),
			'error-prefix'                      => __( 'Error: ', 'kairos-wp' ),
			'error-login-connection'            => __( 'Connection error during login attempt.', 'kairos-wp' ),
			'error-register-empty-fields'       => __( 'Please complete all fields.', 'kairos-wp' ),
			'error-register-password-mismatch'  => __( 'Passwords do not match.', 'kairos-wp' ),
			'error-register-password-short'     => __( 'Password must be at least 8 characters.', 'kairos-wp' ),
			'error-register-captcha-incomplete' => __( 'Please complete the CAPTCHA.', 'kairos-wp' ),
			'error-register-captcha-verification' => __( 'Error verifying CAPTCHA.', 'kairos-wp' ),
			'success-register'                  => __( 'Registration almost complete! We have sent a verification email to %s. Please click the link in the email to activate your account and then you can log in. If you don\'t see it, please check your spam folder.', 'kairos-wp' ),
			'error-register-unknown'            => __( 'Unknown registration error.', 'kairos-wp' ),
			'error-register-email-exists'       => __( 'This email is already registered. Try logging in.', 'kairos-wp' ),
			'error-register-domain-exists'      => __( 'This website domain has already been registered with another account.', 'kairos-wp' ),
			'error-register-captcha-failed'     => __( 'CAPTCHA verification failed. Try again.', 'kairos-wp' ),
			'error-register-connection'         => __( 'Connection error during account registration.', 'kairos-wp' ),
			'error-forgot-password-empty-email' => __( 'Please enter your email address.', 'kairos-wp' ),
			'success-forgot-password-link-sent' => __( 'If an account exists with that email, a password reset link has been sent.', 'kairos-wp' ),
			'success-logout'                    => __( 'You have been logged out.', 'kairos-wp' ),

			// Nuevos mensajes de error para un manejo más detallado
			'error-missing-required-fields'     => __( 'Please complete all required fields.', 'kairos-wp' ),
			'error-invalid-email-format'        => __( 'The email address provided is not a valid format.', 'kairos-wp' ),
			// 'error-password-too-short' ya existe como 'error-register-password-short'
			'error-captcha-service-error'       => __( 'There was a problem with the CAPTCHA service. Please try again later.', 'kairos-wp' ),
			'error-database-error'              => __( 'A database error occurred. Please try again later.', 'kairos-wp' ),
			'error-internal-server-error'       => __( 'An internal server error occurred. Please try again later.', 'kairos-wp' ),
			'error-missing-auth-header'         => __( 'Authentication information is missing. Please log in.', 'kairos-wp' ),
			'error-token-expired'               => __( 'Your session has expired. Please log in again.', 'kairos-wp' ),
			'error-invalid-token'               => __( 'Your session is invalid. Please log in again.', 'kairos-wp' ),
			'error-invalid-token-payload'       => __( 'Invalid session data. Please log in again.', 'kairos-wp' ),
			'error-user-not-found'              => __( 'User account not found.', 'kairos-wp' ),
			// 'error-profile-not-found' ya existe para la cuota
			'error-db-fetch-error'              => __( 'Error retrieving data from the database.', 'kairos-wp' ),
			'error-invalid-reset-token'         => __( 'The password reset link is invalid or has been used.', 'kairos-wp' ),
			'error-expired-reset-token'         => __( 'The password reset link has expired. Please request a new one.', 'kairos-wp' ),
			'error-missing-verification-token'  => __( 'The verification link is missing necessary information.', 'kairos-wp' ),
			'error-invalid-verification-token'  => __( 'The email verification link is invalid or has been used.', 'kairos-wp' ),
			'success-email-already-verified'    => __( 'This email address has already been verified. You can now log in.', 'kairos-wp' ), // Para el caso de éxito informativo
			'error-expired-verification-token'  => __( 'The email verification link has expired. Please try registering again or contact support if the issue persists.', 'kairos-wp' ),
			'error-quota-exceeded'              => __( '¡Oh no! Parece que has consumido todos tus tokens. Para continuar creando plugins, por favor, adquiere un nuevo paquete de tokens desde la página de Ajustes.', 'kairos-wp' ),
			'quota-usage-label'                 => __( 'Uso de Tokens:', 'kairos-wp' ),
			'quota-exceeded-tooltip'            => __( 'Has excedido tu cuota de tokens actual.', 'kairos-wp' ),
			// Cadenas para _cpt-screen.js
			'cpt-text-req-changed'              => __( 'Requirements changed. Please generate code again.', 'kairos-wp' ),
			'cpt-error-saving-review'           => __( 'Error saving review.', 'kairos-wp' ),
			'cpt-error-ajax-saving-review'      => __( 'AJAX error saving review.', 'kairos-wp' ),
			'cpt-error-no-code-type-fallback'   => __( 'No %s code available to view.', 'kairos-wp' ),
			// Cadenas para _ui-helpers.js (ThickBox)
			'thickbox-title-pablo'              => __( 'Pablo (AI Developer)', 'kairos-wp' ),
			'thickbox-title-alex'               => __( 'Alex (AI Reviewer)', 'kairos-wp' ),
			'thickbox-title-lola'               => __( 'Lola (AI Consultant)', 'kairos-wp' ),
			'thickbox-title-system'             => __( 'System Processing', 'kairos-wp' ),
			'thickbox-title-default'            => __( 'Processing...', 'kairos-wp' ),
			'thickbox-message-default'          => __( 'Processing...', 'kairos-wp' ),
			'text-coming-soon'                  => __( '(Coming Soon)', 'kairos-wp' ),
			// Nuevos mensajes para errores de dominio
			'error-domain-already-registered-by-other' => __( 'Este dominio web ya está registrado por otra cuenta de Kairos WP.', 'kairos-wp' ),
			'error-domain-association-failed'   => __( 'No se pudo asociar este dominio web con tu cuenta.', 'kairos-wp' ),
			'error-missing-current-domain'      => __( 'Error crítico: El dominio actual del sitio web no se envió al servidor.', 'kairos-wp' ),
			// Mensajes para canje de cupones
			'error-coupon-code-empty'           => __( 'Please enter a coupon code.', 'kairos-wp' ),
			'success-coupon-redeemed'           => __( 'Coupon redeemed successfully! Tokens have been added to your account.', 'kairos-wp' ),
			'error-coupon-invalid'              => __( 'Invalid or expired coupon code.', 'kairos-wp' ),
		);
	}

	// Removed the duplicate public wrapper and the duplicate private method below

	// ... (rest of the class methods like activation, textdomain loading etc.)
	// Make sure activation and textdomain loading methods exist or are inherited correctly
	public function get_kairos_wp_activate() {
		// Placeholder for activation logic if needed
        $this->set_flush_rewrite_flag(); // Ensure rules are flushed on activation
	}

	public function get_kairos_wp_redirect_after_activation() {
		// Placeholder for redirect logic if needed
	}

	public function get_kairos_wp_load_textdomain() {
		load_plugin_textdomain( 'kairos-wp', false, dirname( plugin_basename( __DIR__ ) ) . '/languages/' );
	}

	// --- Rewrite Rules & Query Vars for Auth Actions ---

	/**
	 * Register rewrite rules and query vars on init.
	 */
	private function kairos_wp_register_rewrites() {
		add_rewrite_rule( '^kairos-verify-email/?$', 'index.php?kairos_auth_action=verify_email', 'top' );
		add_rewrite_rule( '^kairos-reset-password/?$', 'index.php?kairos_auth_action=reset_password', 'top' );
		add_rewrite_tag( '%kairos_auth_action%', '([^&]+)' );

		// Flush rules on activation/deactivation is better, but for dev let's add a temporary check
		// IMPORTANT: Remove this flush in production, handle it on activation hook.
		if ( get_option( 'kairos_wp_flush_rewrites_flag' ) ) {
			flush_rewrite_rules();
			delete_option( 'kairos_wp_flush_rewrites_flag' );
		}
	}
	public function get_kairos_wp_register_rewrites() {
		$this->kairos_wp_register_rewrites();
	}

	/**
	 * Set flag to flush rules on next init (call this on activation).
	 */
	public function set_flush_rewrite_flag() {
		update_option( 'kairos_wp_flush_rewrites_flag', true );
	}


	// --- Template Handling for Auth Actions ---

	/**
	 * Check for our auth action query var and load custom template if matched.
	 */
	private function kairos_wp_template_redirect_handler() {
		global $wp_query;

		$auth_action = $wp_query->get( 'kairos_auth_action' );

		if ( ! empty( $auth_action ) ) {
			if ( $auth_action === 'verify_email' ) {
				// Load the verification template
				$this->load_auth_template( 'verify-email' );
				exit; // Prevent default WP template loading
			} elseif ( $auth_action === 'reset_password' ) {
				// Load the password reset template
				$this->load_auth_template( 'reset-password' );
				exit; // Prevent default WP template loading
			}
		}
	}
	public function get_kairos_wp_template_redirect_handler() {
		$this->kairos_wp_template_redirect_handler();
	}

	/**
	 * Helper to load auth template files.
	 *
	 * @param string $template_name Name of the template (e.g., 'verify-email').
	 */
	private function load_auth_template( $template_name ) {
		// Define path to templates directory (consider creating this)
		$template_path = plugin_dir_path( dirname( __FILE__ ) ) . 'templates/' . sanitize_file_name( $template_name ) . '-page.php';

		if ( file_exists( $template_path ) ) {
			// Set headers to prevent caching if needed
			nocache_headers();
			// Include the template file
			include( $template_path );
		} else {
			// Fallback if template is missing
			wp_die( esc_html__( 'Authentication template file not found.', 'kairos-wp' ) );
		}
	}

}
