<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-render.php';
require_once plugin_dir_path( __DIR__ ) . '/framework/includes/class-kairos-wp-post-type-framework.php';

class Kairos_WP_Post_Type extends Kairos_WP_Post_Type_Framework {
	public $render;

	public function __construct() {
		$this->render = new Kairos_WP_Render();
	}

	private function kairos_wp_register_settings() {
		parent::get_kairos_wp_register_settings();

		// REMOVED: Supabase Settings Fields
		// REMOVED: Google OAuth Setting Field

		// REMOVED: Reviewer Model Setting field and registration

		// --- ADDED: Uninstall Settings Section and Field ---
		add_settings_section(
			'kairos_wp_uninstall_section', // Section ID
			__( 'Uninstall Settings', 'kairos-wp' ), // Title
			array( $this->render, 'render_uninstall_section_callback' ), // Callback for section description (in Render class)
			'kairos_wp_settings' // Page slug where this section appears
		);

		add_settings_field(
			'kairos_wp_delete_data_on_uninstall', // Option ID
			__( 'Data Deletion', 'kairos-wp' ), // Field Title
			array( $this->render, 'render_delete_data_checkbox' ), // Callback to render the field (in Render class)
			'kairos_wp_settings', // Page slug
			'kairos_wp_uninstall_section' // Section ID
		);

		register_setting(
			'kairos_wp_uninstall_options', // Option group name (used in settings_fields)
			'kairos_wp_delete_data_on_uninstall', // Option name
			array(
				'type'              => 'boolean',
				'sanitize_callback' => 'rest_sanitize_boolean', // Use WP core boolean sanitization
				'default'           => true, // Default to deleting data
			)
		);
		// --- END: Uninstall Settings ---
	}

	public function get_kairos_wp_register_settings() {
		$this->kairos_wp_register_settings();
	}

	private function kairos_wp_enable_meta_revisions( $revisioned_keys ) {
		$revisioned_keys = parent::get_kairos_wp_enable_meta_revisions( $revisioned_keys );

		if ( ! in_array( '_confidence_level', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_confidence_level';
		}
		if ( ! in_array( '_suggestions', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_suggestions';
		}
		if ( ! in_array( '_confidence_level_explanation', $revisioned_keys, true ) ) {
			$revisioned_keys[] = '_confidence_level_explanation';
		}
		return $revisioned_keys;
	}

	public function get_kairos_wp_enable_meta_revisions( $revisioned_keys ) {
		return $this->kairos_wp_enable_meta_revisions( $revisioned_keys );
	}

	private function kairos_wp_enable_meta_revision_fields( $fields ) {
		$fields = parent::get_kairos_wp_enable_meta_revision_fields( $fields );

		$fields['_confidence_level']             = esc_html__( 'Confidence Level', 'kairos-wp' );
		$fields['_confidence_level_explanation'] = esc_html__( 'Confidence Explanation', 'kairos-wp' );
		$fields['_suggestions']                  = esc_html__( 'Suggestions', 'kairos-wp' );
		return $fields;
	}

	public function get_kairos_wp_enable_meta_revision_fields( $fields ) {
		return $this->kairos_wp_enable_meta_revision_fields( $fields );
	}

	/**
	 * Overrides the parent method to ensure the correct render object and method name are used for the settings page callback.
	 */
	public function get_kairos_wp_add_menu_pages() {
		// Replicate the menu registration logic here, ensuring $this->render is used.

		add_menu_page(
			esc_html__( 'Kairos WP', 'kairos-wp' ),
			esc_html__( 'Kairos WP', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-home', // Menu slug
			array( $this->render, 'get_kairos_wp_render_home_page' ), // Use $this->render (Kairos_WP_Render instance)
			'dashicons-lightbulb',
			3
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Home', 'kairos-wp' ),
			esc_html__( 'Home', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-home',
			array( $this->render, 'get_kairos_wp_render_home_page' ) // Use $this->render
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Plugins', 'kairos-wp' ),
			esc_html__( 'Kairos Plugins', 'kairos-wp' ),
			'manage_options',
			'edit.php?post_type=kairos_wp'
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Add New Kairos Plugin', 'kairos-wp' ),
			esc_html__( 'Add New Kairos Plugin', 'kairos-wp' ),
			'manage_options',
			'post-new.php?post_type=kairos_wp'
		);

		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Settings', 'kairos-wp' ),
			esc_html__( 'Settings', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-settings', // Menu slug
			// *** THE KEY CHANGE: Use $this->render (Kairos_WP_Render) and the correct public method name ***
			array( $this->render, 'kairos_wp_render_settings_page' ) // Use the actual public render method name
		);

		// Add Documentation Submenu Page
		add_submenu_page(
			'kairos-wp-home',
			esc_html__( 'Kairos Documentation', 'kairos-wp' ),
			esc_html__( 'Documentation', 'kairos-wp' ),
			'manage_options',
			'kairos-wp-documentation',
			array( $this->render, 'get_kairos_wp_render_documentation_page' ) // Use $this->render
		);
	}
}
