<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __DIR__ ) . '/framework/includes/class-kairos-wp-render-framework.php';
require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-core.php';

class Kairos_WP_Render extends Kairos_WP_Render_Framework {
	public $core;

	public function __construct() {
		$this->core = new Kairos_WP_Core();
	}

	private function kairos_wp_is_save_disabled() {
		if ( is_multisite() ) {
			return true;
		} elseif ( /* For Example: Is Plugin File Editor Active */ false ) {
			return true;
		} else {
			return false;
		}
	}

	public function get_kairos_wp_is_save_disabled() {
		return $this->kairos_wp_is_save_disabled();
	}

	// REMOVED DEPRECATED FUNCTION: kairos_wp_render_download_buttons() and its wrapper

	private function kairos_wp_render_confidence( $post ) {
		// This will be used within the Alex card on the delivery screen
		$confidence_level             = get_post_meta( $post->ID, '_confidence_level', true );
		$confidence_level_explanation = get_post_meta( $post->ID, '_confidence_level_explanation', true );
		if ( $confidence_level ) {
			?>
			<?php
			$confidence_class = '';
			if ( $confidence_level >= 75 ) { // Umbral para verde: 75 o más
				$confidence_class = 'confidence-level-high';
			} elseif ( $confidence_level >= 50 ) { // Umbral para naranja: 50 a 74
				$confidence_class = 'confidence-level-medium';
			} else { // Menos de 50 será rojo
				$confidence_class = 'confidence-level-low';
			}
			?>
			<div id="kairos-wp-confidence-level" class="kairos-wp-confidence-score <?php echo esc_attr( $confidence_class ); ?>" data-confidence-level="<?php echo esc_attr( $confidence_level ); ?>">
				<h5><?php esc_html_e( 'Confidence Level:', 'kairos-wp' ); ?> <?php echo esc_html( $confidence_level ) . '%'; ?></h5>
				<div class="kairos-wp-tooltip-container">
					<i class="dashicons dashicons-info kairos-wp-confidence-info" aria-hidden="true"></i>
					<div class="kairos-wp-tooltip-text"><?php esc_html_e( 'We use a special AI prompt to obtain this value. Values above 90% represent a good result.', 'kairos-wp' ); ?></div>
				</div>
			</div>
			<h5><?php esc_html_e( 'Explanation:', 'kairos-wp' ); ?></h5>
			<p id="kairos-wp-confidence-explanation-text"><?php echo wp_kses_post( $confidence_level_explanation ); // Use wp_kses_post to allow basic HTML if Alex returns it ?></p>

			<?php
		} else {
			?>
			<div id="kairos-wp-confidence-level" data-confidence-level="<?php echo esc_attr( $confidence_level ); ?>">
				<h5><?php esc_html_e( 'Confidence Level:', 'kairos-wp' ); ?> <?php esc_html__( 'N/A', 'kairos-wp' ); ?></h5>
				<div class="kairos-wp-tooltip-container">
						<i class="dashicons dashicons-info kairos-wp-confidence-info" aria-hidden="true"></i>
						<div class="kairos-wp-tooltip-text"><?php esc_html__( 'Confidence Level is currently unavailable.', 'kairos-wp' ); ?></div>
				</div>
			</div>
			<?php // Add the paragraph structure even when confidence is N/A, JS will update it ?>
			<h5><?php esc_html_e( 'Explanation:', 'kairos-wp' ); ?></h5>
			<p id="kairos-wp-confidence-explanation-text"><?php esc_html_e( 'Review pending or explanation not available.', 'kairos-wp' ); ?></p>
			<?php
		}
	}

	public function get_kairos_wp_render_confidence( $post ) {
		$this->kairos_wp_render_confidence( $post );
	}

	/**
	 * Renders the content for the Token Economy metabox.
	 * Displays available balance (via JS) and consumption for the current plugin.
	 *
	 * @param WP_Post $post The current post object.
	 */
	private function kairos_wp_render_token_economy_metabox( $post ) {
		// Fetch token usage data specific to this plugin post
		$lola_initial_total_tokens = get_post_meta( $post->ID, '_lola_initial_total_tokens', true );
		$lola_refine_total_tokens  = get_post_meta( $post->ID, '_lola_refine_total_tokens', true );
		$pablo_total_tokens        = get_post_meta( $post->ID, '_pablo_total_tokens', true );
		$alex_total_tokens         = get_post_meta( $post->ID, '_alex_total_tokens', true );
		// Recalculate cumulative from individual parts for accuracy
		$cumulative_tokens = ( is_numeric( $lola_initial_total_tokens ) ? intval( $lola_initial_total_tokens ) : 0 ) +
							 ( is_numeric( $lola_refine_total_tokens ) ? intval( $lola_refine_total_tokens ) : 0 ) +
							 ( is_numeric( $pablo_total_tokens ) ? intval( $pablo_total_tokens ) : 0 ) +
							 ( is_numeric( $alex_total_tokens ) ? intval( $alex_total_tokens ) : 0 );


		// Format numbers as integers with thousand separators
		$format_tokens = function( $value ) {
			return is_numeric( $value ) ? number_format_i18n( intval( $value ) ) : '0';
		};

		?>
		<div class="kairos-wp-token-economy-metabox">
			<p>
				<?php // Etiqueta actualizada por JS a 'Uso de Tokens:' ?>
				<strong><?php esc_html_e( 'Available Balance:', 'kairos-wp' ); // El JS lo cambiará a 'Uso de Tokens:' ?></strong>
				<span id="kairos-wp-available-token-balance-value"><?php esc_html_e( 'Loading...', 'kairos-wp' ); ?></span>
			</p>
			<hr>
			<h4><?php esc_html_e( 'Consumption for this Plugin:', 'kairos-wp' ); ?></h4>
			<?php // Usar la clase 'kairos-wp-consumption-list' que espera _ui-helpers.js ?>
			<ul class="kairos-wp-consumption-list" style="list-style: none; padding-left: 0; margin-top: 5px; margin-bottom: 10px;">
				<?php // Los items <li> se generarán/actualizarán dinámicamente por JS (updateListItem en _ui-helpers.js) ?>
				<?php // Dejamos estos como fallback si JS falla o para el renderizado inicial antes de que JS actúe ?>
				<li data-agent="lola_initial" <?php if (empty( $lola_initial_total_tokens ) || intval($lola_initial_total_tokens) == 0) echo 'style="display:none;"'; ?>>
					<?php printf( esc_html__( 'Lola (Initial): %s', 'kairos-wp' ), '<strong>' . esc_html( $format_tokens( $lola_initial_total_tokens ) ) . '</strong>' ); ?>
				</li>
				<li data-agent="lola_refine" <?php if (empty( $lola_refine_total_tokens ) || intval($lola_refine_total_tokens) == 0) echo 'style="display:none;"'; ?>>
					<?php printf( esc_html__( 'Lola (Refine): %s', 'kairos-wp' ), '<strong>' . esc_html( $format_tokens( $lola_refine_total_tokens ) ) . '</strong>' ); ?>
				</li>
				<li data-agent="pablo" <?php if (empty( $pablo_total_tokens ) || intval($pablo_total_tokens) == 0) echo 'style="display:none;"'; ?>>
					<?php printf( esc_html__( 'Pablo (Generate): %s', 'kairos-wp' ), '<strong>' . esc_html( $format_tokens( $pablo_total_tokens ) ) . '</strong>' ); ?>
				</li>
				<li data-agent="alex" <?php if (empty( $alex_total_tokens ) || intval($alex_total_tokens) == 0) echo 'style="display:none;"'; ?>>
					<?php printf( esc_html__( 'Alex (Review): %s', 'kairos-wp' ), '<strong>' . esc_html( $format_tokens( $alex_total_tokens ) ) . '</strong>' ); ?>
				</li>
			</ul>
			<?php // Usar la clase 'kairos-wp-cumulative-total' que espera _ui-helpers.js ?>
			<p class="kairos-wp-cumulative-total" style="border-top: 1px solid #eee; padding-top: 10px; <?php if (empty( $cumulative_tokens ) || intval($cumulative_tokens) == 0) echo 'display:none;'; ?>">
				<?php 
				$total_consumed_text = __( 'Total Consumed: %s', 'kairos-wp' );
				// Asegurarse de que %s esté presente para el reemplazo en JS, si no, añadirlo.
				// La función JS updateTokenMetaboxDisplay ya maneja esto.
				?>
				<strong><?php printf( esc_html( $total_consumed_text ), esc_html( $format_tokens( $cumulative_tokens ) ) ); ?></strong>
			</p>
		</div>
		<?php
	}

	// Public wrapper for the new metabox renderer
	public function get_kairos_wp_render_token_economy_metabox( $post ) {
		$this->kairos_wp_render_token_economy_metabox( $post );
	}

	/**
	 * Renders the Kairos WP Home page.
	 * Includes JavaScript for authentication check and redirection.
	 * If authenticated, it then includes the actual welcome page content.
	 * @param mixed $post The post object (or null if not in post context), passed by WordPress hook if applicable.
	 */
	public function get_kairos_wp_render_home_page( $post ) { // Matched parent signature
		// Script to check authentication status and redirect if not logged in
		?>
		<script type="text/javascript">
			document.addEventListener('DOMContentLoaded', function() {
				// Ensure kairosWpApi and verifyToken are available
				if (typeof window.kairosWpApi !== 'undefined' && typeof window.kairosWpApi.verifyToken === 'function') {
					window.kairosWpApi.verifyToken().then(function(userData) {
						if (!userData || !userData.id) {
							// User is not authenticated or token is invalid
							console.log('[Kairos WP Home] User not authenticated, redirecting to settings page.');
							window.location.href = '<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-settings' ) ); ?>';
						} else {
							// User is authenticated, allow home page content to be displayed
							console.log('[Kairos WP Home] User authenticated: ', userData.email);
							// Make sure the main content div is visible if previously hidden by JS or CSS
							var homeContent = document.getElementById('kairos-wp-home-content-wrapper');
							if (homeContent) {
								homeContent.style.display = 'block';
							}
						}
					}).catch(function(error) {
						// Error during token verification, assume not authenticated and redirect
						console.error('[Kairos WP Home] Error verifying token:', error);
						window.location.href = '<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-settings' ) ); ?>';
					});
				} else {
					// Critical error: API object not available. Redirect or show error.
					console.error('[Kairos WP Home] kairosWpApi.verifyToken is not available. Cannot check authentication status.');
					// Fallback: redirect to settings, as auth status cannot be determined.
					// window.location.href = '<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-settings' ) ); ?>';
					// Or display an error message directly on the page:
					var bodyElement = document.querySelector('.wrap.kairos-wp-welcome-wrapper');
					if (bodyElement) {
						bodyElement.innerHTML = '<p style="color: red; font-weight: bold;">' + (typeof kairos_wp_get_message !== 'undefined' ? kairos_wp_get_message('error_auth_verify_failed_js') : 'Error: Credentials cannot be verified. Try reloading the page or contact support.') + '</p>';
					}
				}
			});
		</script>
		<?php

		// Wrapper div for the actual home content, initially hidden by JS if redirection occurs
		// Or, we can rely on the JS to not let this part be "seen" if redirection happens quickly.
		// For robustness, the JS above should ideally prevent this PHP from outputting if redirecting.
		// However, PHP runs first. So, the JS will execute after this PHP has prepared the page.
		// The redirection will then occur if needed.
		echo '<div id="kairos-wp-home-content-wrapper">'; // This div might be briefly visible
		$welcome_framework_path = plugin_dir_path( dirname( __FILE__ ) ) . 'framework/views/welcome-framework.php';
		if ( file_exists( $welcome_framework_path ) ) {
			include $welcome_framework_path;
		} else {
			echo '<p>' . esc_html__( 'Error: Welcome page content file not found.', 'kairos-wp' ) . '</p>';
		}
		echo '</div>';
	}


	/**
	 * Renders the token usage section. (DEPRECATED - Moved to metabox)
	 *
	 * @param WP_Post $post The current post object.
	 */
	// REMOVED DEPRECATED FUNCTION: kairos_wp_render_token_usage()

	// REMOVED OBSOLETE FUNCTION: kairos_wp_render_reviewer_model_field

	// REMOVED OBSOLETE FUNCTION: get_kairos_wp_render_reviewer_model_field

	/**
	 * Renders the initial screen where Lola asks for the plugin idea.
	 * Based on image 06.jpg
	 *
	 * @param WP_Post $post The current post object.
	 */
	public function get_kairos_wp_render_initial_lola_screen( $post ) {
		// Get any previously saved initial prompt if the user comes back without generating
		$initial_prompt = get_post_meta( $post->ID, '_initial_prompt', true );
		?>
		<div class="kairos-wp-agent-card kairos-wp-lola">
			<div class="kairos-wp-agent-header">
				<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/images/avatars/lola_avatar.png' ); ?>" alt="<?php esc_attr_e( 'Lola Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar">
				<div>
					<h3 class="kairos-wp-agent-name"><?php esc_html_e( 'Lola (AI Consultant)', 'kairos-wp' ); ?></h3>
				</div>
			</div>
			<div class="kairos-wp-agent-message">
				<p><?php esc_html_e( 'Hi! I\'m Lola, your AI consultant. I\'m here to help you define the perfect plugin. Tell me what you need.', 'kairos-wp' ); ?></p> <?php // Humanized ?>
			</div>
		</div>

		<?php // API Key Notice Removed ?>

		<div class="kairos-wp-form-group kairos-wp-chat-input-area">
			<label for="kairos-wp-initial-prompt"><strong><?php esc_html_e( 'Describe your plugin idea (the post title will be the plugin name):', 'kairos-wp' ); ?></strong></label>
			<textarea id="kairos-wp-initial-prompt" name="kairos_wp_initial_prompt" rows="8" style="width:100%;" placeholder="<?php esc_attr_e( 'Example: I need a plugin that displays a modal pop-up to confirm the user\'s age upon entering the site. This pop-up should block navigation and prevent visiting the site until the age of majority is confirmed...', 'kairos-wp' ); ?>"><?php echo esc_textarea( $initial_prompt ); ?></textarea>
		</div>
		<div class="kairos-wp-form-group">
			<button id="kairos-wp-send-to-lola-btn" type="button" class="button button-primary kairos-wp-action-button" disabled>
				<?php esc_html_e( 'Send Idea to Lola', 'kairos-wp' ); ?>
			</button>
			<span id="kairos-wp-lola-initial-thinking" style="display: none; margin-left: 10px;">
				<span class="spinner is-active" style="float: none; vertical-align: middle;"></span>
				<?php esc_html_e( 'Lola is reviewing your idea...', 'kairos-wp' ); ?>
			</span>
		</div>
		<?php
	}

	/**
	 * Renders the screen where Lola shows the refined requirements.
	 * Based on image 05.jpg
	 *
	 * @param WP_Post $post The current post object.
	 */
	public function get_kairos_wp_render_refined_lola_screen( $post ) {
		$functional_requirements = get_post_meta( $post->ID, '_functional_requirements', true );
		?>
		<div class="kairos-wp-agent-card kairos-wp-lola">
			<div class="kairos-wp-agent-header">
				<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/images/avatars/lola_avatar.png' ); ?>" alt="<?php esc_attr_e( 'Lola Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar">
				<div>
					<h3 class="kairos-wp-agent-name"><?php esc_html_e( 'Lola (AI Consultant)', 'kairos-wp' ); ?></h3>
				</div>
			</div>
			<div class="kairos-wp-agent-message">
				<p><?php esc_html_e( 'All set! I\'ve reviewed your idea and prepared these functional requirements for Pablo to get to work. Take a look!', 'kairos-wp' ); ?></p> <?php // Humanized ?>
			</div>
		</div>

		<?php // API Key Notice Removed ?>

		<div class="kairos-wp-form-group">
			<h4><?php esc_html_e( 'Refined Functional Requirements:', 'kairos-wp' ); ?></h4>
			<div class="kairos-wp-requirements-display">
				<?php echo nl2br( esc_html( $functional_requirements ) ); ?>
			</div>
			<button id="kairos-wp-edit-requirements-btn" type="button" class="button button-secondary"><?php esc_html_e( 'Edit Requirements Manually', 'kairos-wp' ); ?></button>
		</div>
		<div class="kairos-wp-form-group">
			<button id="kairos-wp-send-to-pablo-btn" type="button" class="button button-primary kairos-wp-action-button">
				<?php esc_html_e( 'Send Requirements to Pablo', 'kairos-wp' ); ?>
			</button>
		</div>
		<?php // Add hidden field for current requirements needed by JS send-to-pablo action ?>
		<div id="kairos-wp-hidden-code-refined" style="display:none;"> <?php // Use a slightly different ID if needed, or reuse the structure ?>
			<pre id="kairos-wp-hidden-requirements"><?php echo esc_html( $functional_requirements ); ?></pre>
		</div>
		<?php
		// --- REMOVED: Redundant rendering of delivery screen here ---
	}

	/**
	 * Renders the delivery screen with Pablo's code and Alex's review.
	 * Based on image 03.jpg
	 *
	 * @param WP_Post $post The current post object.
	 */
	public function get_kairos_wp_render_delivery_screen( $post ) {
		// Restore fetching code
		$suggestions_json = get_post_meta( $post->ID, '_suggestions', true );
		$suggestions      = ! empty( $suggestions_json ) ? json_decode( $suggestions_json, true ) : array();
		$php_code         = get_post_meta( $post->ID, '_php_output', true );
		$js_code          = get_post_meta( $post->ID, '_js_output', true );
		$css_code         = get_post_meta( $post->ID, '_css_output', true );
		// Remove temporary checks, rely on !empty() below
		// $has_php_code     = !empty(get_post_meta( $post->ID, '_php_output', true ));
		// $has_js_code      = !empty(get_post_meta( $post->ID, '_js_output', true ));
		// $has_css_code     = !empty(get_post_meta( $post->ID, '_css_output', true ));

		?>
		<?php // --- Pablo's Card (First) --- ?>
		<div class="kairos-wp-agent-card kairos-wp-pablo">
			<div class="kairos-wp-agent-header">
				<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/images/avatars/pablo_avatar.png' ); ?>" alt="<?php esc_attr_e( 'Pablo Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar">
				<div>
					<h3 class="kairos-wp-agent-name"><?php esc_html_e( 'Pablo (AI Developer)', 'kairos-wp' ); ?></h3>
				</div>
			</div>
			<div class="kairos-wp-agent-message">
				<p><?php esc_html_e( 'Finished! I\'ve programmed your plugin according to the requirements Lola gave me. Here\'s the code!', 'kairos-wp' ); ?></p> <?php // Humanized ?>
			</div>
			<h4><?php esc_html_e( 'Code generated by Pablo', 'kairos-wp' ); ?></h4>
			<div id="kairos-wp-code-actions">
				<?php // Restore original button logic based on fetched code variables ?>
				<button class="button kairos-wp-view-code-btn" data-type="php"><?php esc_html_e( 'View PHP', 'kairos-wp' ); ?></button>
				<button class="button kairos-wp-view-code-btn" data-type="js" style="<?php echo empty( $js_code ) ? 'display:none;' : ''; ?>"><?php esc_html_e( 'View JS', 'kairos-wp' ); ?></button>
				<button class="button kairos-wp-view-code-btn" data-type="css" style="<?php echo empty( $css_code ) ? 'display:none;' : ''; ?>"><?php esc_html_e( 'View CSS', 'kairos-wp' ); ?></button>
			<button class="button kairos-wp-test-start"><?php esc_html_e( 'Test in Playground', 'kairos-wp' ); ?></button>
			<button class="button kairos-wp-download-zip"><?php esc_html_e( 'Download ZIP', 'kairos-wp' ); ?></button>
			<?php // REMOVED: Button to request review ?>
		</div>
		<div id="kairos-wp-install-section">
				<label class="kairos-wp-checkbox-label" style="display: none;"> <!-- Ocultar checkbox ya que el botón estará siempre deshabilitado -->
					<input type="checkbox" id="kairos-wp-confirm-tested" style="display: none;">
					<?php esc_html_e( 'I have tested this code and confirm it works.', 'kairos-wp' ); ?>
				</label>
				<button id="kairos-wp-install-plugin-btn-disabled" class="button button-primary" disabled="disabled" title="<?php esc_attr_e( 'This feature will be available soon.', 'kairos-wp' ); ?>">
					<?php esc_html_e( 'Install Plugin', 'kairos-wp' ); ?> <?php echo esc_html__( '(Coming Soon)', 'kairos-wp' ); ?>
				</button>
			</div>
			<button class="button button-secondary"><?php esc_html_e( 'Mark as Finished', 'kairos-wp' ); ?></button> <?php // TODO: Add functionality to this button ?>
		</div>

		<?php // --- Alex's Card (Second) --- ?>
		<div class="kairos-wp-agent-card kairos-wp-alex">
			<div class="kairos-wp-agent-header">
				<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/images/avatars/alex_avatar.png' ); ?>" alt="<?php esc_attr_e( 'Alex Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar">
				<div>
					<h3 class="kairos-wp-agent-name"><?php esc_html_e( 'Alex (AI Reviewer)', 'kairos-wp' ); ?></h3>
				</div>
			</div>
			<div class="kairos-wp-agent-message">
				<?php // Show different message based on whether review exists ?>
				<?php if ( empty( get_post_meta( $post->ID, '_confidence_level', true ) ) ) : ?>
					<p id="kairos-wp-alex-pending-review"><?php esc_html_e( 'Now it\'s my turn! I\'m reviewing Pablo\'s code...', 'kairos-wp' ); ?></p> <?php // Humanized ?>
					<p id="kairos-wp-alex-review-intro" style="display: none;"><?php esc_html_e( 'Review complete! I\'ve analyzed Pablo\'s code. Here\'s my evaluation:', 'kairos-wp' ); ?></p> <?php // Humanized ?>
				<?php else : ?>
					<p id="kairos-wp-alex-pending-review" style="display: none;"><?php esc_html_e( 'Now it\'s my turn! I\'m reviewing Pablo\'s code...', 'kairos-wp' ); ?></p> <?php // Humanized ?>
					<p id="kairos-wp-alex-review-intro"><?php esc_html_e( 'Review complete! I\'ve analyzed Pablo\'s code. Here\'s my evaluation:', 'kairos-wp' ); ?></p> <?php // Humanized ?>
				<?php endif; ?>
			</div>

			<?php // Wrap review content so it can be hidden/shown easily - Using alternative syntax for conditional style ?>
			<div id="kairos-wp-alex-review-content" <?php if ( empty( get_post_meta( $post->ID, '_confidence_level', true ) ) ) : ?>style="display: none;"<?php endif; ?>>
				<?php $this->get_kairos_wp_render_confidence( $post ); ?>

				<?php // REMOVED: Call to render token usage here, moved to metabox ?>
				<?php // $this->kairos_wp_render_token_usage( $post ); ?>

				<?php // Always render the structure, JS will handle visibility ?>
				<h5><?php esc_html_e( 'Improvement Suggestions:', 'kairos-wp' ); ?></h5>
				<ul class="kairos-wp-suggestions-checkbox-list">
					<?php // Populate suggestions if they exist ?>
					<?php if ( ! empty( $suggestions ) && is_array( $suggestions ) ) : ?>
						<?php foreach ( $suggestions as $index => $suggestion ) : ?>
							<li>
								<label class="kairos-wp-checkbox-label">
									<input type="checkbox" class="kairos-wp-suggestion-checkbox" value="<?php echo esc_attr( $suggestion ); ?>">
									<?php echo esc_html( $suggestion ); ?>
								</label>
							</li>
						<?php endforeach; ?>
					<?php endif; ?>
				</ul>
				<button id="kairos-wp-apply-suggestions-btn" type="button" class="button button-secondary" style="<?php echo ( empty( $suggestions ) ? 'display:none;' : '' ); ?>"><?php esc_html_e( 'Add Selected Suggestions to Improvement Request', 'kairos-wp' ); ?></button>
				<?php // endif; // This endif; should be here, closing the if ( ! empty( $suggestions ) ... ) block ?>
				<p class="kairos-wp-no-suggestions" style="<?php echo ( ! empty( $suggestions ) ? 'display:none;' : '' ); ?>"><em><?php esc_html_e( 'No specific suggestions were provided.', 'kairos-wp' ); ?></em></p>
			</div> <?php // End #kairos-wp-alex-review-content ?>
		</div> <?php // End Alex Card ?>

		<?php // --- Lola's Improvements Card (Third) --- ?>
		<div class="kairos-wp-agent-card kairos-wp-lola">
			<div class="kairos-wp-agent-header">
				<img src="<?php echo esc_url( plugin_dir_url( dirname( __FILE__ ) ) . 'assets/images/avatars/lola_avatar.png' ); ?>" alt="<?php esc_attr_e( 'Lola Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar">
				<div>
					<h3 class="kairos-wp-agent-name"><?php esc_html_e( 'Lola (AI Consultant)', 'kairos-wp' ); ?></h3>
				</div>
			</div>
			<div class="kairos-wp-agent-message">
				<p><?php esc_html_e( 'Do you need any changes or improvements to the plugin? Describe what you need or select Alex\'s suggestions, and I will prepare them for Pablo.', 'kairos-wp' ); ?></p> <?php // Already quite humanized ?>
			</div>
			<div class="kairos-wp-form-group">
				<label for="kairos-wp-improvements-input"><strong><?php esc_html_e( 'Improvement Request:', 'kairos-wp' ); ?></strong></label>
				<textarea id="kairos-wp-improvements-input" name="kairos_wp_improvements" rows="5" style="width:100%;" placeholder="<?php esc_attr_e( 'Describe the changes you want to request here...', 'kairos-wp' ); ?>"></textarea>
			</div>
			<div class="kairos-wp-form-group">
				<button id="kairos-wp-send-improvements-btn" type="button" class="button button-primary kairos-wp-action-button">
					<?php esc_html_e( 'Refine Improvements with Lola', 'kairos-wp' ); ?>
				</button>
				<span id="kairos-wp-lola-improvements-thinking" style="display: none; margin-left: 10px;"> <?php // Added thinking indicator for Lola ?>
					<span class="spinner is-active" style="float: none; vertical-align: middle;"></span>
					<?php esc_html_e( 'Lola is processing your improvements...', 'kairos-wp' ); ?>
				</span>
			</div>
		</div>

		<?php // Hidden code fields for modals/download/JS - Restored esc_html() with actual variables ?>
		<div id="kairos-wp-hidden-code" style="display:none;">
			<pre id="kairos-wp-hidden-php"><?php echo esc_html( $php_code ); ?></pre>
			<pre id="kairos-wp-hidden-js"><?php echo esc_html( $js_code ); ?></pre>
			<pre id="kairos-wp-hidden-css"><?php echo esc_html( $css_code ); ?></pre>
			<?php // Add hidden field for current requirements needed by JS refine_improvements action ?>
			<pre id="kairos-wp-hidden-requirements"><?php echo esc_html( get_post_meta( $post->ID, '_functional_requirements', true ) ); ?></pre>
		</div>
		<?php
	}

	/**
	 * Renders the HTML structure for standard popups (Alert, Confirm, Edit, Code View).
	 * NOTE: Agent Loader Overlay is now rendered separately via admin_footer hook.
	 */
	public function get_kairos_wp_render_popups_and_overlays() {
		// Moved from the old kairos_wp_after_title_render function
		?>
		<div id="kairos-wp-loader-overlay"> <!-- Changed ID -->
			<div id="kairos-wp-loader-container"> <!-- Changed ID -->
				<p id="kairos-wp-loader-text"><?php esc_html_e( 'Don\'t refresh the page', 'kairos-wp' ); ?></p>
				<div id="kairos-wp-loader"></div> <!-- Changed ID -->
			</div>
		</div>

		<?php // REMOVED LEGACY POPUP: kairos-wp-rephrased-popup-overlay ?>

		<?php /* Note: Removed kairos-wp-rephrased-user-prompt-popup-overlay as it seemed redundant with the one above */ ?>

		<div id="kairos-wp-alert-popup-overlay" class="kairos-wp-popup-overlay kairos-wp-popup-error"> <!-- Changed ID/classes -->
			<div id="kairos-wp-alert-popup-content" class="kairos-wp-popup-content"> <!-- Changed ID/class -->
				<h3><?php esc_html_e( 'Alert', 'kairos-wp' ); ?></h3>
				<div id="kairos-wp-alert-popup-content-text" class="kairos-wp-popup-content-text"> <!-- Changed ID/class -->
					<p id="kairos-wp-alert-text"></p> <!-- Changed ID -->
				</div>
				<div id="kairos-wp-alert-popup-content-buttons" class="kairos-wp-popup-content-buttons"> <!-- Changed class -->
					<button id="kairos-wp-alert-ok" class="button button-primary button-large" data-action="close"><?php esc_html_e( 'OK', 'kairos-wp' ); ?></button>
				</div>
			</div>
		</div>

		<div id="kairos-wp-refresh-popup-overlay" class="kairos-wp-popup-overlay"> <!-- Changed ID/class -->
			<div id="kairos-wp-refresh-popup-content" class="kairos-wp-popup-content"> <!-- Changed ID/class -->
				<h3><?php esc_html_e( 'Refresh Required', 'kairos-wp' ); ?></h3>
				<div class="kairos-wp-popup-content-text"> <!-- Changed class -->
					<p id="kairos-wp-refresh-text"></p> <!-- Changed ID -->
				</div>
				<div class="kairos-wp-popup-content-buttons"> <!-- Changed class -->
					<button id="kairos-wp-refresh" class="button button-secondary button-large"><?php esc_html_e( 'Refresh Page', 'kairos-wp' ); ?></button>
				</div>
			</div>
		</div>

		<div id="kairos-wp-confirm-popup-overlay" class="kairos-wp-popup-overlay kairos-wp-popup-error"> <!-- Changed ID/classes -->
			<div id="kairos-wp-confirm-popup-content" class="kairos-wp-popup-content"> <!-- Changed ID/class -->
				<h3><?php esc_html_e( 'Confirm Action', 'kairos-wp' ); ?></h3>
				<div class="kairos-wp-popup-content-text"> <!-- Changed class -->
					<p id="kairos-wp-confirm-text"></p> <!-- Changed ID -->
				</div>
				<div class="kairos-wp-popup-content-buttons"> <!-- Changed class -->
					<button id="kairos-wp-confirm-yes" class="button button-primary button-large"><?php esc_html_e( 'Yes, Confirm', 'kairos-wp' ); ?></button>
					<button id="kairos-wp-confirm-no" class="button button-secondary button-large"><?php esc_html_e( 'No, Cancel', 'kairos-wp' ); ?></button>
				</div>
			</div>
		</div>

		<div id="kairos-wp-edit-popup-overlay" class="kairos-wp-popup-overlay"> <!-- Changed ID/class -->
			<div id="kairos-wp-edit-popup-content" class="kairos-wp-popup-content"> <!-- Changed ID/class -->
				<h3 id="kairos-wp-edit-popup-title"><?php esc_html_e( 'Edit', 'kairos-wp' ); ?></h3>
				<div class="kairos-wp-popup-content-text"> <!-- Changed class -->
				<textarea id="kairos-wp-edit-textarea" rows="10" cols="150"></textarea> <!-- Changed ID -->
				</div>
				<div class="kairos-wp-popup-content-buttons"> <!-- Changed class -->
					<button id="kairos-wp-edit-submit" class="button button-primary button-large" data-type=""><?php esc_html_e( 'Submit Changes', 'kairos-wp' ); ?></button>
					<button id="kairos-wp-edit-cancel" class="button button-secondary button-large"><?php esc_html_e( 'Cancel Edit', 'kairos-wp' ); ?></button>
				</div>
			</div>
		</div>

		<?php // REMOVED HTML for Pablo Loading Overlay ?>

		<?php // REMOVED HTML for Pablo Loading Overlay ?>

		<?php // REMOVED HTML for Alex Loading Overlay ?>

		<?php // REMOVED Generic Agent Loader Overlay HTML (moved to separate function for footer hook) ?>

		<?php // Code View Modal ?>
		<div id="kairos-wp-code-modal" style="display: none;">
			<div class="kairos-wp-modal-content">
				<div class="kairos-wp-modal-header">
					<h3 id="kairos-wp-code-modal-title"></h3>
					<button class="kairos-wp-modal-close">&times;</button>
				</div>
				<div class="kairos-wp-modal-body">
					<pre id="kairos-wp-code-modal-content"></pre>
				</div>
				<div class="kairos-wp-modal-footer">
					<button class="button kairos-wp-modal-copy"><?php esc_html_e( 'Copy Code', 'kairos-wp' ); ?></button>
					<button class="button button-secondary kairos-wp-modal-close"><?php esc_html_e( 'Close', 'kairos-wp' ); ?></button>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Renders the HTML for the generic agent loader modal.
	 * Intended to be hooked into 'admin_footer'.
	 */
	public function render_agent_loader_modal_html() {
		// Check if we are on the correct CPT edit screen before rendering
		global $pagenow, $post;
		if ( ( 'post.php' === $pagenow || 'post-new.php' === $pagenow ) && isset( $post->post_type ) && 'kairos_wp' === $post->post_type ) {
			?>
			<?php // Container for ThickBox inline content - MUST be hidden ?>
			<div id="kairos-wp-thickbox-loader-container" style="display: none;">
				<?php // Content that will be displayed inside ThickBox ?>
				<div id="kairos-wp-thickbox-loader-content" class="kairos-wp-thickbox-agent-content"> <?php // Use a new class for styling if needed ?>
					<img id="kairos-wp-thickbox-loader-avatar" src="" alt="<?php esc_attr_e( 'Agent Avatar', 'kairos-wp' ); ?>" class="kairos-wp-agent-avatar-loading">
					<h3 id="kairos-wp-thickbox-loader-text" style="margin-top: 1em; margin-bottom: 0.5em;"></h3> <?php // Add some basic margin ?>
					<p style="margin-bottom: 1em;"><?php esc_html_e( 'This may take a few minutes. Do not refresh the page!', 'kairos-wp' ); ?></p> <?php // Add some basic margin ?>
					<div class="kairos-wp-loading-spinner"></div>
				</div>
			</div>
			<?php
		}
	}

	public function get_kairos_wp_render_documentation_page() {
		// Existing documentation page content can go here if any.
		// For now, we assume it's a new page or we are replacing existing simple content.
		?>
		<div class="wrap kairos-wp-documentation-page">
			<h1><?php esc_html_e( 'Kairos WP Documentation', 'kairos-wp' ); ?></h1>

			<section id="tutorial">
				<h2><?php esc_html_e( 'How to Use Kairos WP (Step-by-Step)', 'kairos-wp' ); ?></h2>
				<p><?php esc_html_e( 'Welcome to Kairos WP! Follow these steps to create your first custom plugin:', 'kairos-wp' ); ?></p>
				<ol>
					<li><?php esc_html_e( 'Navigate to "Kairos WP" > "Add New Kairos Plugin" in your WordPress admin menu.', 'kairos-wp' ); ?></li>
					<li><?php esc_html_e( 'Enter a descriptive title for your plugin. This will also be the name of the generated plugin.', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Phase 1: Describe your Idea to Lola (AI Consultant)', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'In Lola\'s input area, clearly describe the functionality you want your plugin to have.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Click "Send Idea to Lola". Lola will process your idea and present "Refined Functional Requirements".', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 2: Review Requirements & Send to Pablo (AI Developer)', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'Carefully review the requirements Lola prepared. You can click "Edit Requirements Manually" to make adjustments.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'If satisfied, click "Send Requirements to Pablo".', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 3: Pablo Generates the Code', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'Pablo will now write the PHP, JavaScript, and CSS code. This may take a few moments.', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 4: Alex Reviews the Code (Automatic)', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'Alex will automatically review Pablo\'s code, providing a confidence level and suggestions.', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 5: Delivery & User Review', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'Inspect the generated code using "View PHP/JS/CSS" buttons.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Test your plugin safely using the "Test in Playground" button.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Download the plugin as a ZIP or, if tested and confirmed working, try "Install Plugin".', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Review Alex\'s confidence level and suggestions.', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 6: Iteration with Lola (Optional)', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'If you need changes, describe them in Lola\'s improvement section or use Alex\'s suggestions. Click "Refine Improvements with Lola" to restart the generation cycle with the new requirements.', 'kairos-wp' ); ?></li>
						</ul>
					</li>
					<li><strong><?php esc_html_e( 'Phase 7: Mark as Finished', 'kairos-wp' ); ?></strong>
						<ul>
							<li><?php esc_html_e( 'Once satisfied, click "Mark as Finished".', 'kairos-wp' ); ?></li>
						</ul>
					</li>
				</ol>
			</section>

			<section id="faq">
				<h2><?php esc_html_e( 'Frequently Asked Questions (FAQ)', 'kairos-wp' ); ?></h2>
				
				<h3><?php esc_html_e( 'What kind of plugins can I create?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'You can create a wide variety of plugins, from simple utility functions (like custom shortcodes or content snippets) to more complex ones involving custom post types or modifications to WordPress behavior. The key is to describe your needs clearly. For very complex plugins, it\'s best to break down the functionality into smaller, manageable requests.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'How long does it take to generate a plugin?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Generation time can vary from a few seconds to a few minutes, depending on the complexity of your request and current server load. Pablo and Alex will keep you updated on their progress.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'What if the generated plugin doesn\'t work as expected?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Don\'t worry! Kairos WP is designed for iteration. Use Lola\'s "Improvement Request" section to describe what went wrong or what needs to change. You can also use Alex\'s suggestions. Lola will refine the requirements, and Pablo and Alex will try again.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'How does the token system work?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Each interaction with the AI agents (Lola, Pablo, Alex) consumes a certain amount of tokens from your quota. You receive an initial free quota upon registration. You can monitor your consumption in the "Token Economy" metabox on the plugin creation screen and in your "Settings" page. If you run out, you can purchase more token packages.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Can I modify the code generated by Kairos WP?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Absolutely! You can view the generated PHP, JS, and CSS code. You can download the plugin as a ZIP file and modify it as you wish if you have coding knowledge. However, if you then request further improvements via Kairos WP, your manual changes might be overwritten unless you incorporate them into your improvement request for Lola.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Is it safe to install the plugins generated by Kairos WP?', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'While Alex (our AI Reviewer) checks the code for quality and potential issues, and we encourage testing in WordPress Playground first, you are ultimately responsible for any code you install on your live site. Always test thoroughly. For critical sites, consider having a developer review complex plugins.', 'kairos-wp' ); ?></p>
			</section>

			<section id="optimizing-requests">
				<h2><?php esc_html_e( 'Tips for Optimizing Your Plugin Requests', 'kairos-wp' ); ?></h2>
				<p><?php esc_html_e( 'To get the best results from Kairos WP and make the most of your tokens, follow these tips:', 'kairos-wp' ); ?></p>
				<ul>
					<li><strong><?php esc_html_e( 'Be Specific and Detailed:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'The more clearly you define what your plugin should do, how it should behave, and even how it might look (if applicable), the better Lola can translate your idea into effective requirements for Pablo. Don\'t assume the AI knows what you mean; spell it out.', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Break Down Complex Ideas:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'If you need a plugin with multiple significant features, consider requesting them as separate, smaller plugins first, or build one feature at a time through iterations. This makes it easier for the AI to focus and reduces the chance of errors.', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Use Clear Language:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Avoid jargon if possible, or explain it if necessary. Write complete sentences and be unambiguous.', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Provide Examples:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'If you have an example of a similar feature on another website, or a specific way you want something to work, describing it can be very helpful (e.g., "I want a contact form similar to the one on example.com, but with an added field for \'Subject\'").', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Review Lola\'s Requirements Carefully:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Before sending the requirements to Pablo, make sure Lola has understood you correctly. If not, use the "Edit Requirements Manually" option to make corrections. This can save a lot of time and tokens.', 'kairos-wp' ); ?></li>
					<li><strong><?php esc_html_e( 'Iterate with Improvements:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'The first version might not be perfect. Use the "Improvement Request" feature. Tell Lola what needs to be changed, added, or removed. This is often more efficient than starting from scratch.', 'kairos-wp' ); ?></li>
				</ul>
			</section>

			<section id="troubleshooting">
				<h2><?php esc_html_e( 'Troubleshooting Common Issues', 'kairos-wp' ); ?></h2>

				<h3><?php esc_html_e( 'The generated plugin doesn\'t do exactly what I asked.', 'kairos-wp' ); ?></h3>
				<p><strong><?php esc_html_e( 'What to do:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'The best approach is to use the "Improvement Request" section. Clearly explain what is different from your expectation or what new behavior you want. Refer back to your original request if needed. Also, ensure you reviewed Lola\'s refined requirements thoroughly before sending them to Pablo, as misunderstandings can start there.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'What to avoid:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Getting frustrated and immediately trying to start over with the exact same vague prompt. Iteration is key!', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'I received an error message from Lola, Pablo, or Alex.', 'kairos-wp' ); ?></h3>
				<p><strong><?php esc_html_e( 'What to do:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Read the error message carefully; it might give you a clue. Try simplifying your request or rephrasing it. If the error mentions API issues or timeouts, it might be a temporary problem with the AI service; you can try again after a short while. If the problem persists even with simple requests, please refer to our support.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'What to avoid:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Repeatedly sending the exact same complex request that caused an error without trying to simplify or modify it.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'The generated plugin causes a PHP error on my site when I activate or use it.', 'kairos-wp' ); ?></h3>
				<p><strong><?php esc_html_e( 'What to do:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'This is why testing in WordPress Playground ("Test in Playground" button) is highly recommended before installing on your live site! If you encounter an error, copy the error message if possible and describe it in the "Improvement Request" section for Lola. The AI team will attempt to fix it.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'What to avoid:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Activating a newly generated plugin directly on a live, critical website without any prior testing.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'I\'ve run out of tokens in my free trial or package.', 'kairos-wp' ); ?></h3>
				<p><strong><?php esc_html_e( 'What to do:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'You can purchase additional token packages from the "Kairos WP" > "Settings" page in your WordPress admin area.', 'kairos-wp' ); ?></p>
				
				<h3><?php esc_html_e( 'A button isn\'t working or the Kairos WP page looks strange.', 'kairos-wp' ); ?></h3>
				<p><strong><?php esc_html_e( 'What to do:', 'kairos-wp' ); ?></strong> 
					<ol>
						<li><?php esc_html_e( 'Try a hard refresh of your browser page (Ctrl+F5 on Windows/Linux, Cmd+Shift+R on Mac). This often resolves caching issues.', 'kairos-wp' ); ?></li>
						<li><?php esc_html_e( 'Ensure your internet connection is stable.', 'kairos-wp' ); ?></li>
						<li><?php esc_html_e( 'Temporarily deactivate other plugins one by one to see if there\'s a conflict (do this on a staging site if possible).', 'kairos-wp' ); ?></li>
						<li><?php esc_html_e( 'Switch to a default WordPress theme (like Twenty Twenty-Four) to check for theme conflicts.', 'kairos-wp' ); ?></li>
					</ol>
				</p>
				<p><strong><?php esc_html_e( 'What to avoid:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Assuming the plugin is completely broken without trying these basic troubleshooting steps.', 'kairos-wp' ); ?></p>
			</section>

			<section id="upcoming-features">
				<h2><?php esc_html_e( 'Exciting Features Coming Soon to Kairos WP!', 'kairos-wp' ); ?></h2>
				<p><?php esc_html_e( 'Our team is constantly working to make Kairos WP even more powerful and intuitive. Here\'s a sneak peek at some of the enhancements currently under development and planned for upcoming releases:', 'kairos-wp' ); ?></p>
				
				<h3><?php esc_html_e( 'Your AI Content Assistant: Create and Manage Site Content with Ease', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Imagine being able to generate blog posts, product descriptions, or page content directly with the help of Kairos WP. We are working to empower our AI agents to not only create plugin functionality but also to assist you in crafting compelling content for your WordPress site.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'How you could use it:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Simply tell Kairos WP: "Create a blog post about the benefits of organic gardening, including a section on composting." Or, "Write a product description for a handmade leather wallet, highlighting its durability and unique design."', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'Benefits:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Save time on content creation, overcome writer\'s block, and ensure your site always has fresh, relevant information for your audience and search engines. Perfect for quickly populating new sections of your site or generating initial drafts.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Supercharge Your Community: Deep BuddyPress Integration', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Building a vibrant online community? We\'re developing features to allow Kairos WP to create custom functionalities specifically for BuddyPress. Extend your social network with unique features tailored to your members.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'How you could use it:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Ask Kairos WP to: "Create a BuddyPress plugin that adds a new \'Hobbies\' tab to user profiles where members can list their interests." Or, "Develop a feature that sends a custom welcome message to new BuddyPress group members."', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'Benefits:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Enhance member engagement, create unique interaction points, and tailor your BuddyPress community to perfectly match its purpose, all without needing to dive into BuddyPress development complexities.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Elevate Your E-commerce: Seamless WooCommerce Enhancements', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'Take your WooCommerce store to the next level! Kairos WP is learning to interact deeply with WooCommerce, allowing you to request custom features, modifications, and new tools for your online shop.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'How you could use it:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Imagine asking Kairos WP: "Generate a WooCommerce extension that adds a custom \'Gift Wrap\' option with an extra fee to the product page." Or, "Create a utility that displays a \'Recently Viewed Products\' slider on the shop page."', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'Benefits:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Increase sales with custom up-sells or product recommendations, improve user experience with tailored shop features, and automate specific e-commerce tasks, giving you a competitive edge.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Advanced Plugin Architecture & Customization: The Next Generation AI Team', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'We\'re significantly upgrading our AI agent team! Soon, Kairos WP will be able to generate plugins with more complex and professional structures (multiple files, classes, etc.). Even more exciting, you\'ll be able to point Kairos WP to an existing open-source plugin from the WordPress repository, and our AI team will help you understand it, modify it, and create your own personalized version (a "fork")!', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'How you could use it:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'For complex plugins: "Design a membership plugin with three access levels, content restriction capabilities, and a custom user dashboard." For forking: "Take the existing \'Simple SEO\' plugin and add a new feature to automatically generate meta descriptions based on post content."', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'Benefits:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Tackle much more ambitious plugin projects with AI assistance. Customize existing popular plugins to perfectly fit your needs without starting from scratch, saving immense development time and leveraging proven codebases.', 'kairos-wp' ); ?></p>

				<h3><?php esc_html_e( 'Beyond Plugins: AI-Powered WordPress Theme Creation and Modification', 'kairos-wp' ); ?></h3>
				<p><?php esc_html_e( 'The ultimate step in WordPress customization! Kairos WP is expanding its horizons to include WordPress themes. Soon, you\'ll be able to describe your ideal website design, and our AI agents will help you generate a new theme or even modify aspects of your existing theme.', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'How you could use it:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Tell Kairos WP: "Create a minimalist blog theme with a two-column layout, a dark mode toggle, and a focus on readability." Or, "Modify my current theme to change the header layout and add a new custom widget area in the footer."', 'kairos-wp' ); ?></p>
				<p><strong><?php esc_html_e( 'Benefits:', 'kairos-wp' ); ?></strong> <?php esc_html_e( 'Achieve truly unique website designs without needing to be a theme developer. Make targeted visual changes to your site with AI guidance, opening up a new realm of creative possibilities for your WordPress presence.', 'kairos-wp' ); ?></p>
			</section>

			<section id="plugin-examples">
				<h2><?php esc_html_e( 'Plugin Ideas: What You Can (and Can\'t) Create with Kairos WP', 'kairos-wp' ); ?></h2>
				
				<div class="kairos-wp-examples-container">
					<div class="kairos-wp-examples-column">
						<h3><?php esc_html_e( '20 Examples of Plugins You CAN Create:', 'kairos-wp' ); ?></h3>
						<p><?php esc_html_e( 'Kairos WP excels at creating plugins with specific, well-defined functionalities. Here are some ideas to get you started:', 'kairos-wp' ); ?></p>
						<ol>
							<li><?php esc_html_e( 'Custom "Under Construction" Page: Mode with admin panel options for message, logo, background image, and countdown timer.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Reusable Contact Info Shortcode: e.g., [contact_details] displaying address, phone, email configurable via plugin options.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Advanced Title Modifier: Add prefixes/suffixes to post titles based on category or post type.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Niche-Specific Calculator: e.g., "Simple Project Cost Calculator" taking hours and rate/hour.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Notification Bar with Timer: Display a dismissible notice bar that disappears after X seconds or on click.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'User Role-Based Redirection: Redirect subscribers to a welcome page and editors to another page after login.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Basic Comment Manager: Auto-close comments on old posts (e.g., after 90 days).', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Simple "Author Spotlight" Widget: Display a specific author\'s photo, name, and short bio (configurable).', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Custom Excerpt Length per Post Type: Different excerpt lengths for posts vs. pages vs. products.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Simple Exit-Intent Popup: Show a message or offer when a user tries to leave the site (mouse movement detection).', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Call-to-Action (CTA) Button Shortcode: e.g., [my_cta text="Buy Now" link="/product"] generating a styled button.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Simple Star Rating System: Allow users to rate posts (1-5 stars) and display average rating.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Add Custom Fields to User Profiles: e.g., "Country" or "Profession" field.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Simple Post View Counter: Display how many times a post has been viewed.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Basic Image Gallery Shortcode: Takes a list of image IDs and displays them in a simple grid.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Incomplete Content Reminder for Editors: Notice in edit screen if post lacks featured image or is too short.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Custom CSS/JS Adder Plugin: Simple options panel to paste CSS or JS code into header/footer.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Simple Table of Contents Generator: Shortcode or auto-function to list H2/H3 headings.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Disable REST API for Non-Logged-In Users: Simple security plugin to restrict REST API access.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Promotional Banner for Specific WooCommerce Products: Display a banner only on certain product/category pages.', 'kairos-wp' ); ?></li>
						</ol>
					</div>

					<div class="kairos-wp-examples-column">
						<h3><?php esc_html_e( '10 Examples of Plugins You CANNOT (Currently) Create:', 'kairos-wp' ); ?></h3>
						<p><?php esc_html_e( 'While Kairos WP is powerful, there are limitations, especially for highly complex plugins or those requiring deep external integrations not yet supported. Here are examples of what might be beyond the current version (though future updates will expand capabilities!):', 'kairos-wp' ); ?></p>
						<ol>
							<li><?php esc_html_e( 'A Full Clone of WooCommerce or Easy Digital Downloads.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'A Page Builder like Elementor or Beaver Builder.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'An Advanced SEO Plugin like Yoast SEO or Rank Math.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'A Complex Social Network Plugin base like BuddyPress.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Plugins requiring deep integrations with multiple complex third-party APIs and OAuth.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Security Plugins with multi-layer protection (Firewall, Malware Scanning).', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Complete Backup and Restore Plugins.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'A Full Learning Management System (LMS) like LearnDash.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Plugins that invasively or unsafely modify WordPress Core.', 'kairos-wp' ); ?></li>
							<li><?php esc_html_e( 'Plugins dependent on specific server hardware or OS-level interactions.', 'kairos-wp' ); ?></li>
						</ol>
					</div>
				</div>
			</section>

			<section id="contact-support">
				<h2><?php esc_html_e( 'Need More Help?', 'kairos-wp' ); ?></h2>
				<p><?php printf( esc_html__( 'If you\'ve gone through the FAQs and troubleshooting tips and still have questions or are experiencing issues, please don\'t hesitate to contact our support team at %s. We\'re here to help!', 'kairos-wp' ), '<a href="mailto:soporte@vanguardhive.com">soporte@vanguardhive.com</a>' ); // Reemplaza con el email de soporte real ?></p>
			</section>

		</div>
		<?php
	}

}
