<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-ajax.php';
require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-core.php';
require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-post-type.php';
require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-render.php'; // Keep require for Render class

class Kairos_WP {
	public $ajax;
	public $core;
	public $post_type;
	public $render; // Keep render property declaration

	public function __construct() {
		$this->ajax      = new Kairos_WP_Ajax();
		$this->core      = new Kairos_WP_Core();
		$this->post_type = new Kairos_WP_Post_Type();
		$this->render    = new Kairos_WP_Render(); // Keep render object instantiation
		
		register_activation_hook( plugin_dir_path( __DIR__ ) . 'kairos-wp-developer-init.php', array( $this->core, 'get_kairos_wp_activate' ) );

		add_action( 'init', array( $this->post_type, 'get_kairos_wp_register_post_type' ) );
		add_action( 'pre_get_posts', array( $this->post_type, 'get_kairos_wp_hide_posts_for_non_admins' ) );
		add_action( 'load-post.php', array( $this->post_type, 'get_kairos_wp_restrict_post_access' ) );
		add_action( 'add_meta_boxes', array( $this->post_type, 'get_kairos_wp_add_output_meta_boxes' ) );
		add_action( 'admin_menu', array( $this->post_type, 'get_kairos_wp_add_menu_pages' ) );
		add_action( 'admin_head', array( $this->post_type, 'get_kairos_wp_highlight_submenu' ) );
		add_action( 'admin_init', array( $this->post_type, 'get_kairos_wp_register_settings' ) );
		add_action( 'admin_init', array( $this->core, 'get_kairos_wp_redirect_after_activation' ) );
		// Restore the original hook for rendering after title
		add_action( 'edit_form_after_title', array( $this, 'get_kairos_wp_after_title_render' ) );
		add_filter( 'wp_post_revision_meta_keys', array( $this->post_type, 'get_kairos_wp_enable_meta_revisions' ) );
		add_filter( '_wp_post_revision_fields', array( $this->post_type, 'get_kairos_wp_enable_meta_revision_fields' ) );
		add_filter( 'enter_title_here', array( $this->post_type, 'get_kairos_wp_change_title_placeholder' ), 10, 2 );

		// REMOVED LEGACY HOOK: save_post_kairos_wp

		add_action( 'admin_enqueue_scripts', array( $this->core, 'get_kairos_wp_enqueue_scripts' ) );
		
		add_action( 'plugins_loaded', array( $this->core, 'get_kairos_wp_load_textdomain' ) );

		add_action( 'wp_ajax_kairos_wp_download_zip', array( $this->ajax, 'kairos_wp_handle_download_zip' ) ); // Prefixed
		add_action( 'wp_ajax_kairos_wp_save_to_plugins', array( $this->ajax, 'kairos_wp_handle_save_to_plugins' ) ); // Prefixed

		// Register the handler for saving edited content (manual FR edit)
		// The 'edit' action was too generic. Assuming kairos_wp_handle_save_manual_edit is the correct one.
		// add_action( 'wp_ajax_edit', array( $this->ajax, 'kairos_wp_handle_edit' ) ); // Keep if still used, or remove if kairos_wp_handle_save_manual_edit replaces it.
		
		// Register handlers for each step of the agent flow
		add_action( 'wp_ajax_kairos_wp_get_token_quota_proxy', array( $this->ajax, 'kairos_wp_get_token_quota_proxy' ) );
		add_action( 'wp_ajax_kairos_wp_save_initial_lola', array( $this->ajax, 'kairos_wp_handle_save_initial_lola' ) );
		add_action( 'wp_ajax_kairos_wp_publish_cpt_before_pablo', array( $this->ajax, 'kairos_wp_publish_cpt_before_pablo' ) ); // New action
		add_action( 'wp_ajax_kairos_wp_save_pablo_results', array( $this->ajax, 'kairos_wp_handle_save_pablo_results' ) );
		add_action( 'wp_ajax_kairos_wp_save_alex_review', array( $this->ajax, 'kairos_wp_handle_save_alex_review' ) );
		add_action( 'wp_ajax_kairos_wp_save_refined_lola', array( $this->ajax, 'kairos_wp_handle_save_refined_lola' ) );
		add_action( 'wp_ajax_kairos_wp_save_manual_edit', array( $this->ajax, 'kairos_wp_handle_save_manual_edit' ) );


		// --- NEW AJAX Action for Marking as Finished ---
		add_action( 'wp_ajax_kairos_wp_mark_as_finished', array( $this->ajax, 'kairos_wp_handle_mark_as_finished' ) ); // Prefixed

		// --- Hooks for Auth Rewrite Rules & Template Handling ---
		add_action( 'init', array( $this->core, 'get_kairos_wp_register_rewrites' ) );
		add_action( 'template_redirect', array( $this->core, 'get_kairos_wp_template_redirect_handler' ) );
		register_activation_hook( plugin_dir_path( __DIR__ ) . 'kairos-wp-developer-init.php', array( $this->core, 'set_flush_rewrite_flag' ) ); // Flush on activation

		// --- Hook to render the generic agent loader modal in the footer ---
		add_action( 'admin_footer', array( $this->render, 'render_agent_loader_modal_html' ) );
	}

	/**
	 * Renders the main UI content after the title field for the 'kairos_wp' CPT.
	 * This will be adapted for the new agent-based UI.
	 *
	 * @param WP_Post $post The current post object.
	 */
	private function kairos_wp_after_title_render( $post ) {
		if ( 'kairos_wp' !== $post->post_type ) {
			return;
		}

		// Ensure the render object is available
		if ( ! isset( $this->render ) || ! is_object( $this->render ) ) {
			// Attempt to instantiate if not already done (should ideally be done in constructor)
			if ( class_exists( 'Kairos_WP_Render' ) ) {
				require_once plugin_dir_path( __FILE__ ) . 'class-kairos-wp-render.php';
				$this->render = new Kairos_WP_Render();
			} else {
				// Fallback or error handling if Render class is missing
				echo '<p>' . esc_html__( 'Error: Render class not found.', 'kairos-wp' ) . '</p>';
				return;
			}
		}

		// Determine which screen to show based on post meta fields
		$php_code   = get_post_meta( $post->ID, '_php_output', true );
		$is_refined = get_post_meta( $post->ID, '_lola_refined', true ); // Check if Lola has refined the initial prompt

		echo '<div id="kairos-wp-main-interface">'; // Wrapper div

		// --- Determine Active Screen ---
		$show_initial_lola = false;
		$show_refined_lola = false;
		$show_delivery     = false;

		if ( ! empty( $php_code ) ) {
			$show_delivery = true;
		} elseif ( $is_refined ) {
			$show_refined_lola = true;
		} else {
			$show_initial_lola = true;
		}

		// --- Always Render All Screen Structures ---

		// Initial Lola Screen
		$initial_lola_style = ! $show_initial_lola ? 'style="display: none;"' : '';
		echo '<div id="kairos-wp-initial-lola-screen" ' . $initial_lola_style . '>';
		if ( method_exists( $this->render, 'get_kairos_wp_render_initial_lola_screen' ) ) {
			$this->render->get_kairos_wp_render_initial_lola_screen( $post );
		} else {
			echo '<p>' . esc_html__( 'Error: Initial Lola screen render method not found.', 'kairos-wp' ) . '</p>';
		}
		echo '</div>';

		// Refined Lola Screen
		$refined_lola_style = ! $show_refined_lola ? 'style="display: none;"' : '';
		echo '<div id="kairos-wp-refined-lola-screen" ' . $refined_lola_style . '>';
		if ( method_exists( $this->render, 'get_kairos_wp_render_refined_lola_screen' ) ) {
			// Note: This function now also renders the hidden delivery screen structure within it.
			// We might need to adjust that if this approach works, to avoid double rendering.
			// For now, let's keep it as is, the outer div controls visibility.
			$this->render->get_kairos_wp_render_refined_lola_screen( $post );
		} else {
			echo '<p>' . esc_html__( 'Error: Refined Lola screen render method not found.', 'kairos-wp' ) . '</p>';
		}
		echo '</div>';

		// Delivery Screen
		// Check if the refined screen already rendered it. If not, render it here.
		// This check is a bit complex. Let's simplify: Assume refined screen DOES NOT render delivery anymore.
		// We will remove the rendering from get_kairos_wp_render_refined_lola_screen in the next step if this works.
		$delivery_style = ! $show_delivery ? 'style="display: none;"' : '';
		echo '<div id="kairos-wp-delivery-screen" ' . $delivery_style . '>';
		if ( method_exists( $this->render, 'get_kairos_wp_render_delivery_screen' ) ) {
			$this->render->get_kairos_wp_render_delivery_screen( $post );
		} else {
			echo '<p>' . esc_html__( 'Error: Delivery screen render method not found.', 'kairos-wp' ) . '</p>';
		}
		echo '</div>';

		// Render Popups and Overlays (needed for all states)
		if ( method_exists( $this->render, 'get_kairos_wp_render_popups_and_overlays' ) ) {
			$this->render->get_kairos_wp_render_popups_and_overlays();
		} else {
			echo '<p>' . esc_html__( 'Error: Popups render method not found.', 'kairos-wp' ) . '</p>';
		}

		// Render hidden fields needed for JS/saving
		?>
		<input type="hidden" id="kairos-wp-status" name="kairos-wp-status" value="0">
		<input type="hidden" id="kairos-wp-first" name="kairos-wp-first" value="<?php echo empty( $functional_requirements ) ? 1 : 0; ?>">
		<input type="hidden" id="hidden-kairos-wp-input" name="hidden-kairos-wp-input">
		<?php wp_nonce_field( 'kairos_wp_nonce', 'kairos_wp_nonce_field' ); ?>
		<?php

		echo '</div>'; // Close wrapper div
	}

	/**
	 * Public wrapper for the main rendering function.
	 *
	 * @param WP_Post $post The current post object.
	 */
	public function get_kairos_wp_after_title_render( $post ) {
		$this->kairos_wp_after_title_render( $post );
	}
}
