<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title><?php esc_html_e( 'Restablecer Contraseña - Kairos WP', 'kairos-wp' ); ?></title>
    <?php wp_head(); ?>
    <style>
        body { font-family: sans-serif; background-color: #f0f0f1; display: flex; justify-content: center; align-items: center; min-height: 100vh; margin: 0; }
        .reset-box { background-color: #fff; padding: 30px 40px; border-radius: 5px; box-shadow: 0 2px 5px rgba(0,0,0,0.1); text-align: left; max-width: 400px; width: 90%; }
        .reset-box h1 { text-align: center; margin-bottom: 25px; }
        .form-group { margin-bottom: 15px; }
        .form-group label { display: block; margin-bottom: 5px; font-weight: bold; }
        .form-group input[type="password"], .form-group input[type="email"] { width: 100%; padding: 8px; border: 1px solid #ccc; border-radius: 3px; box-sizing: border-box; }
        .spinner { display: inline-block; vertical-align: middle; border: 4px solid rgba(0, 0, 0, 0.1); border-left-color: #0073aa; border-radius: 50%; width: 16px; height: 16px; animation: spin 1s linear infinite; margin-left: 5px; }
        @keyframes spin { to { transform: rotate(360deg); } }
        #reset-message { margin-top: 15px; font-weight: bold; text-align: center; }
        #reset-message.success { color: green; }
        #reset-message.error { color: red; }
        .login-link { margin-top: 20px; display: block; text-align: center; }
        .button-primary { background-color: #0073aa; border-color: #006799; color: white; text-decoration: none; padding: 8px 12px; border-radius: 3px; cursor: pointer; }
        .button-primary:hover { background-color: #005177; }
        .button-primary:disabled { background-color: #a0a5aa; border-color: #949494; cursor: default; }
    </style>
</head>
<body>
    <div class="reset-box">
        <h1><?php esc_html_e( 'Restablecer Contraseña', 'kairos-wp' ); ?></h1>
        <div id="reset-form-container">
            <form id="kairos-wp-reset-password-form">
                <p><?php esc_html_e( 'Introduce tu nueva contraseña a continuación.', 'kairos-wp' ); ?></p>
                <div class="form-group">
                    <label for="kairos-wp-reset-new-password"><?php esc_html_e( 'Nueva Contraseña', 'kairos-wp' ); ?></label>
                    <input type="password" id="kairos-wp-reset-new-password" name="new_password" required>
                </div>
                 <div class="form-group">
                    <label for="kairos-wp-reset-confirm-password"><?php esc_html_e( 'Confirmar Nueva Contraseña', 'kairos-wp' ); ?></label>
                    <input type="password" id="kairos-wp-reset-confirm-password" name="confirm_password" required>
                </div>
                <p>
                    <button type="submit" id="kairos-wp-reset-button" class="button-primary"><?php esc_html_e( 'Guardar Nueva Contraseña', 'kairos-wp' ); ?></button>
                    <span id="kairos-wp-reset-spinner" class="spinner" style="display: none;"></span>
                </p>
            </form>
        </div>
        <div id="reset-message"></div>
        <a href="<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-settings' ) ); ?>" id="login-link" class="login-link" style="display: none;"><?php esc_html_e( 'Ir a Ajustes / Login', 'kairos-wp' ); ?></a>
    </div>

    <script type="text/javascript">
        document.addEventListener('DOMContentLoaded', function() {
            const formContainer = document.getElementById('reset-form-container');
            const messageDiv = document.getElementById('reset-message');
            const loginLink = document.getElementById('login-link');
            const resetForm = document.getElementById('kairos-wp-reset-password-form');
            const newPasswordField = document.getElementById('kairos-wp-reset-new-password');
            const confirmPasswordField = document.getElementById('kairos-wp-reset-confirm-password');
            const resetButton = document.getElementById('kairos-wp-reset-button');
            const spinner = document.getElementById('kairos-wp-reset-spinner');

            const urlParams = new URLSearchParams(window.location.search);
            const token = urlParams.get('token');

            if (!token) {
                formContainer.style.display = 'none';
                messageDiv.textContent = '<?php echo esc_js( __( 'Error: Falta el token de reseteo.', 'kairos-wp' ) ); ?>';
                messageDiv.className = 'error';
                loginLink.style.display = 'block';
                return;
            }

            resetForm.addEventListener('submit', function(event) {
                event.preventDefault();
                messageDiv.textContent = '';
                messageDiv.className = '';
                spinner.style.display = 'inline-block';
                resetButton.disabled = true;

                const newPassword = newPasswordField.value;
                const confirmPassword = confirmPasswordField.value;

                if (newPassword.length < 8) {
                    messageDiv.textContent = '<?php echo esc_js( __( 'La contraseña debe tener al menos 8 caracteres.', 'kairos-wp' ) ); ?>';
                    messageDiv.className = 'error';
                    spinner.style.display = 'none';
                    resetButton.disabled = false;
                    return;
                }

                if (newPassword !== confirmPassword) {
                    messageDiv.textContent = '<?php echo esc_js( __( 'Las contraseñas no coinciden.', 'kairos-wp' ) ); ?>';
                    messageDiv.className = 'error';
                    spinner.style.display = 'none';
                    resetButton.disabled = false;
                    return;
                }

                const functionUrl = 'https://fprkfdfnakfskmihodrc.supabase.co/functions/v1/auth-reset-password';

                fetch(functionUrl, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                    body: JSON.stringify({ token: token, new_password: newPassword })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        formContainer.style.display = 'none'; // Hide form on success
                        messageDiv.textContent = '<?php echo esc_js( __( '¡Contraseña restablecida con éxito!', 'kairos-wp' ) ); ?>';
                        messageDiv.className = 'success';
                    } else {
                        let errorMsg = '<?php echo esc_js( __( 'Error desconocido al restablecer la contraseña.', 'kairos-wp' ) ); ?>';
                         if (data.error === 'INVALID_RESET_TOKEN' || data.error === 'EXPIRED_RESET_TOKEN') {
                            errorMsg = '<?php echo esc_js( __( 'Error: El enlace de reseteo no es válido o ha expirado.', 'kairos-wp' ) ); ?>';
                            formContainer.style.display = 'none'; // Hide form if token is invalid/expired
                        } else if (data.message) {
                            errorMsg = data.message;
                        }
                        messageDiv.textContent = errorMsg;
                        messageDiv.className = 'error';
                    }
                    loginLink.style.display = 'block'; // Show login link after process
                })
                .catch(error => {
                    console.error('Error calling reset function:', error);
                    messageDiv.textContent = '<?php echo esc_js( __( 'Error de conexión al restablecer la contraseña.', 'kairos-wp' ) ); ?>';
                    messageDiv.className = 'error';
                    loginLink.style.display = 'block';
                })
                .finally(() => {
                    spinner.style.display = 'none';
                    // Keep button disabled on success, re-enable only on specific errors if needed
                    if (!messageDiv.classList.contains('success')) {
                         resetButton.disabled = false;
                    }
                });
            });
        });
    </script>
    <?php wp_footer(); ?>
</body>
</html>
