<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title><?php esc_html_e( 'Verificando Email - Kairos WP', 'kairos-wp' ); ?></title>
    <?php wp_head(); // Include necessary WP headers, maybe some basic styles? ?>
    <style>
        body { font-family: sans-serif; background-color: #f0f0f1; display: flex; justify-content: center; align-items: center; min-height: 100vh; margin: 0; }
        .verification-box { background-color: #fff; padding: 30px 40px; border-radius: 5px; box-shadow: 0 2px 5px rgba(0,0,0,0.1); text-align: center; max-width: 400px; }
        .spinner { display: inline-block; vertical-align: middle; border: 4px solid rgba(0, 0, 0, 0.1); border-left-color: #0073aa; border-radius: 50%; width: 24px; height: 24px; animation: spin 1s linear infinite; margin-bottom: 15px; }
        @keyframes spin { to { transform: rotate(360deg); } }
        #verification-message { margin-top: 15px; font-weight: bold; }
        #verification-message.success { color: green; }
        #verification-message.error { color: red; }
        .login-link { margin-top: 20px; display: inline-block; padding: 10px 15px; background-color: #0073aa; color: white; text-decoration: none; border-radius: 3px; }
    </style>
</head>
<body>
    <div class="verification-box">
        <h1><?php esc_html_e( 'Verificación de Email', 'kairos-wp' ); ?></h1>
        <div id="verification-status">
            <div class="spinner"></div>
            <p><?php esc_html_e( 'Verificando tu token, por favor espera...', 'kairos-wp' ); ?></p>
        </div>
        <div id="verification-message"></div>
        <a href="<?php echo esc_url( admin_url( 'admin.php?page=kairos-wp-settings' ) ); ?>" id="login-link" class="login-link" style="display: none;"><?php esc_html_e( 'Ir a Ajustes / Login', 'kairos-wp' ); ?></a>
    </div>

    <script type="text/javascript">
        document.addEventListener('DOMContentLoaded', function() {
            const statusDiv = document.getElementById('verification-status');
            const messageDiv = document.getElementById('verification-message');
            const loginLink = document.getElementById('login-link');
            const urlParams = new URLSearchParams(window.location.search);
            const token = urlParams.get('token');

            if (!token) {
                statusDiv.style.display = 'none';
                messageDiv.textContent = '<?php echo esc_js( __( 'Error: Falta el token de verificación.', 'kairos-wp' ) ); ?>';
                messageDiv.className = 'error';
                loginLink.style.display = 'inline-block';
                return;
            }

            const functionUrl = 'https://fprkfdfnakfskmihodrc.supabase.co/functions/v1/auth-verify-email';

            fetch(functionUrl, {
                method: 'POST', // Send as POST with token in body
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ token: token })
            })
            .then(response => response.json())
            .then(data => {
                statusDiv.style.display = 'none'; // Hide spinner
                if (data.success) {
                    if (data.message === 'EMAIL_ALREADY_VERIFIED') {
                         messageDiv.textContent = '<?php echo esc_js( __( 'Tu email ya ha sido verificado anteriormente.', 'kairos-wp' ) ); ?>';
                    } else {
                         messageDiv.textContent = '<?php echo esc_js( __( '¡Email verificado correctamente!', 'kairos-wp' ) ); ?>';
                    }
                    messageDiv.className = 'success';
                } else {
                    let errorMsg = '<?php echo esc_js( __( 'Error desconocido durante la verificación.', 'kairos-wp' ) ); ?>';
                    if (data.error === 'INVALID_VERIFICATION_TOKEN') {
                        errorMsg = '<?php echo esc_js( __( 'Error: El enlace de verificación no es válido.', 'kairos-wp' ) ); ?>';
                    } else if (data.error === 'EXPIRED_VERIFICATION_TOKEN') {
                        errorMsg = '<?php echo esc_js( __( 'Error: El enlace de verificación ha expirado.', 'kairos-wp' ) ); ?>';
                    } else if (data.message) {
                        errorMsg = data.message; // Use message from API if available
                    }
                    messageDiv.textContent = errorMsg;
                    messageDiv.className = 'error';
                }
                loginLink.style.display = 'inline-block'; // Show login link after process
            })
            .catch(error => {
                console.error('Error calling verification function:', error);
                statusDiv.style.display = 'none';
                messageDiv.textContent = '<?php echo esc_js( __( 'Error de conexión durante la verificación.', 'kairos-wp' ) ); ?>';
                messageDiv.className = 'error';
                loginLink.style.display = 'inline-block';
            });
        });
    </script>
    <?php wp_footer(); ?>
</body>
</html>
