<?php
/**
 * Kairos WP Uninstall
 *
 * Handles data cleanup when the plugin is uninstalled (deleted) from WordPress.
 *
 * @package Kairos_WP
 */

// Exit if accessed directly.
if ( ! defined( 'WP_UNINSTALL_PLUGIN' ) ) {
	exit;
}

// Check if the user wants to delete data.
// Default to true (delete data) if the option doesn't exist for some reason.
$delete_data = get_option( 'kairos_wp_delete_data_on_uninstall', true );

if ( $delete_data ) {

	// --- Delete Custom Post Type Posts ---
	$kairos_posts_args = array(
		'post_type'      => 'kairos_wp',
		'posts_per_page' => -1, // Get all posts
		'post_status'    => 'any', // Include drafts, trash, etc.
		'fields'         => 'ids', // Only get IDs for efficiency
	);

	$kairos_posts = get_posts( $kairos_posts_args );

	if ( ! empty( $kairos_posts ) ) {
		foreach ( $kairos_posts as $post_id ) {
			wp_delete_post( $post_id, true ); // true = force delete, bypass trash
		}
	}

	// --- Delete Plugin Options ---
	delete_option( 'kairos_wp_delete_data_on_uninstall' );

	// Note: Other specific plugin options that might have existed in very old versions
	// (like 'kairos_wp_api_key', 'kairos_wp_primary_provider', 'kairos_wp_google_api_key')
	// are assumed to be no longer present or relevant for new installations.
	// If upgrading from a very old version, these might remain in the DB
	// but are not actively used by current versions.

	// The plugin does not currently use custom transients with a specific prefix,
	// user meta that needs special deletion here, or custom database tables.
}

// Note: This script does NOT delete the user accounts created via the Vercel/Supabase system,
// as those exist outside of the WordPress database managed by this plugin.
// It also does not delete the generated plugin files saved in wp-content/plugins/.
